
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s6\x00\x00\x00y\x08\x00e\x00\x00\x01Wn\x14\x00\x01\x01\x01e\x01\x00d\x00\x00\x83\x01\x00\x82\x01\x00Yn\x01\x00Xe\x00\x00e\x02\x00e'
        b'\x03\x00d\x01\x00d\x02\x00\x83\x04\x00\x01d\x03\x00S)\x04z\x1afintech package not loadeds\xf6-\x00\x00PYARMOR\x00\x00\x03\x05\x00\x17'
        b'\r\r\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xb6-\x00\x00\x00\x00\x00\x00F\xfeDV$0y\xeaY\xc7q\xfb\x9b\xda\xc0\xcd\x00\x00\x00\x00\x00\x00\x00\x00\xe5\xfc\xe5\xc6c\x91\x87O\x14LJ\xd7\xe9'
        b'\x1com\xecFN\x14\xd9"\x1b%vg\x83\x8c\x92\xd8\xc7\xfdF7\x02K&\x9a\x1e\x8e\x15\xd2\xd7\xff\xb8*8Lg9S\x96\xe4"\xc5G\x10\x8f\x8e\xaf\xf5\x14a\'\xf5\xfcv\x80]\xca\xec\xc3\xa6\xc3\x19\xae\x0c'
        b"\x88\xe5\x05I@\x0b\x894\x8bX&\xc2\x19iia:\x1fo\xda\r\xec\x83/\xd7\xb3\xa4 )#'\xf4\xfd]\xbd\xf0\xa1f\x1e\xcf\x19\xc2'\xdc\xd9h\x98\x8dF\xd3`\xc1^M\x84t_\xcd\xc7|\x00\x8d6\x02"
        b'.]\xfe\xd1o\xee\xb2v\x1dM\x1c.R\xec\x1c\x9b4\x87\xc2{\x8f\x84\xf5\xbf\xf8j\x0b\';s\xeak\xcdG\xc8c\xdcN\x84\xa5"\xe4\xa3\xe2F\xef\x0f"\xee";`\x0e\xb9:\xf0T\xe8\xb1\x1bk2\x0c\x9d'
        b'c\xd9\xaa\xf3\xdeJ0q\xc3\x13~\xd0I\xad3\x16^\x93?\xda\x00\xd1\x0f\xa0\xf0\xd1w\xbb\x88\xb6\xf2\xfc\xfe\xb4\x1d\xf6\xa7\x9a\xfaD\xf8<\x14R6x\\~\x13\xb9\x98\xf5>\x92\x90\xce\x92  \xb1Q\x8e\xad\xcd'
        b'M\xcd\xfc\\s\xfaH`U8\xce\x90j\x18\t\xcb\x8a\x02\x90\x9c\xf53\x97\xfeLd\xd1>\xf3\xf9\x9d\xc6\x86\x93\x0fx\xa2\xaa\x19h\xd7a\x00\x17\x10\x06OI\xb6I\x11\x06\x88\x1cUx\xda\xa5d\xc3J\xc2\xa0\\'
        b'5\xfb\xea\xa6\x80\x90\xd0r\xed\x99\x8e\x81\xdd\xc8\xbf\xea6>p\x81\xc4\xf3 ^\x98\xd9\xf12\xef\xbdJ\xde\x99\x11\xec\xf7\x0b\xabR\xe6\xfa\xfc\xd0N{\xec\xe7\x98\xea\x7fgTI\xdd\x1cnh\xbf9\x9eU\xbc\xf6\x99'
        b'\x11Df\xb5\xa4\x18\xf6,\x1fJ\x0f\xd7\x04z("R"5\xe2\xbc\xf8\xc4\x0c-~\xb3\\i5\x13\xbb\xe6lAO\x9d\x07F9\xe6\x1fM\xdd5\x8c\xb6\xaf5\x1c\xb6\n\xf1\x10=\xec\xb0\xbap\x1fJN\x99\xc5'
        b'\xe4\r\x0f\xc8S\x13\xe2S$r]\xb9>\x97\xe7\xea\x938bD\xe3\x985\xaadO\xa1\xc4\xbc\xa4B\x9b\x95D#\x15\x99P<\tk\xe4\xfc\x93v\xf3\xe6\xf0\x1e\xc8\xc38\xc0it\xbb|!JC\xb59\x86-'
        b'\x11\xc6\x05\xe4|\x0e\xfb\xda\xd3G$hF\xb1#\xa2c\xf0l\xc5q\xf9\xfb4n\xed\x96\xb9\t\xfb\x84CN\x1440\xca3 \x7f\xa2\x9c\x08\xa5\x86j\xe1\xb3\x9dW\x12\xa3W\xbb(\x99z\xae)H\xd3bM\xf4'
        b'-\xe2Sf\xf8\xfd\xf7w\xa8/\xf6\x97z\xde3(\xa1f\xcb\xb7\x14\x9fz\xad\x1a\x80$\xe9\n\xe3^R\x05\xc7\xf2f\xe3 \x8d\xc1\x91T\x1aD.\xb0\xfb\xb6|Gnt\x1aH\x00\x04\x8a\xd8\x8cu\xeet\x84n'
        b'XhO\xe0\xe48UyL\x87\xc9G\xf8R\xe8\x80\x97\x84\x8f\x93-\xfc\xc3\xe6\x0c\nV\xed\x02|H\x88\xbb\xb9D\x03\xb2In\x08Q\x97\xaa\xd3jo\xdd\x0f\xc4\xcf\xd9]r\x85\x1a\xde \xe5\xceM\xf9\xado\xc1'
        b"lo\x8c\x85\x0e&:\xc4\xe1.0^(\xb4'\x02\x06\x84\xe4\xef\xbd\x11_~\xc7\xc6\xaa\x89tE1M\xd4t\xbe7\x00l1\xb2\x8eF\xd8\x81\x12g=t3rZ\xfb\x94GH\xeaM\xcd\xa7z\xcf<\xd3\xf3"
        b'$\x8c\x8c90o\xd1\xb3\t\x1e\xd5\x82\xb6\xbe\xd9\x10\xc4E&\x95\xad\xceuy\xb9\x88\xfa|\xae~h\xa4sIw\x8b\x90\xa9\xd7\x1a\x00\x7fj\x1f\x84#4d\x0e\xbcp|\x08n\xc2\x9d\xf2@\x08\xb1=\x11\x81\xe8'
        b'J\x86\x83\xa7mt\x92\x9cF\xca\x1e7|`\xca4N\xe5\xcf|\xf3R\xcby\xfdv\x10\t\xf2N\x9dN\xd1\t\x96!\xe9\xaeT\xb71=d\xe6\x97\xe1k.\xad\xc5\x1f\xe5Yw\x83h\x06\x03\xf4\x1e\x8f\xd9\\]'
        b'\xe9\xae\xcc\x8e* \xa9\x9e\x80\xc0s\xea\x82X\xa5\x1c\xb0q7U\x81\xfc7\x9fy\xfc\t\x98\x95\xdf;/\x1a\xd2\r.\xbe:\x9a\xb5\xfb\x92\xfb\x94U\x8aN\xad\xcc\xb6\x00@.\xacy\x1e\xa4\xff\x07]\xab{\x08\xca'
        b'\xd7:_HE\xd4$c\xe0\xeb<Fz`\xe9\x11\xe9E\xf9z]\x9d\xf1`\x0f\x90\xeb~\x05\xa3(aM0\xe69y\xcf\xe0\xb4\xf6\xf4P\xbe\x13\x94\xb7<\xad"}\xbd\xeb\x97hE\\\xc29\x00w\xb4\xd6\xfe'
        b'\xac\xfa\x960\xfd\xf7\x81\xf70\xd5\x04o\xeco\xa2)M\x11\xa3u" \x17(\xf2\xad\x0fQ\xaf6\x1ew\xd1\x04\x8d{\xab\xbe\xbdw\xb0\x19`\x1f!\x1d\xf7[\xd4\xc8\xed\x81to\x80gi\x80l ,\x83#\xa3'
        b'\x8c>\x0bX\xe4\x8d6\x7f\xfe\xdf\x13\xc0\xe5j\x80\x92\xccV\xdc\xec\x9a\xca\xd1:\x99\xa5\x05\xd4\xfe\xd1n\x8b\x99J-K\x88\x0fF-\xd0[\xfd\xf3\xc1\xa5;Zw\x8d\xf9\x10WK\xe9\x1f\x1fl\xda\x13_\\\x84\xac'
        b'u\xf0%\x12\xaf?\x98\xda\xbeIo\xd8Z\xc0{\x14R!\xea\xd53\x15\xb6*\xca\x91\xbd\xe0\x88\xcc\x15\xbf\xd8\xed\xe7\x0e.\x14\xff\x85\xb3\x1at\x97\x11\x16\xd1$j<H\xdbK\xe4\xcf?"S\rm\xf8\x8f\xf5p'
        b"\xd9\xfd})G\xa3Y5\x92\x0c\x03I\xa8S\x8cf\x9a\x10\x8a\x00=U)\xa5\x92\xf0\xc6\xf8\xde^N\xeb\xef\xeb7\xfb\x1d/\x14-\x95\x19\xae\x06mU\x00w\x10\rP\x18\xc7\n\xdd'u_\x80#5\xad\xb0\xd9"
        b'\x9fV\x9d\xf9\xc6\xc0\xbcr\x1e\x8fT5I1\x0e\xf7D!\x83\x86\xdc\x1eqN*S0\xcdn\x91l\t\xcf7sQ\xb3\xa8\xd4\xe9\xb9\xba\xd9\xd9\x13Q\xbf\x8b\xa5\x97\xe2\xd7\x95Fj`ys\xd2\xd5U\x86I\x91'
        b'S\xdf\xdeD\n4\xa8\x12\xf2\xa0-\x9f\x1bn\x05\x8a&\xbdy\xb1b\t\xbaL\x9aH\xf3\xd9\xa8\xb1CN\xf4\x06o\xb9\xae\x9c\xea\xcf\xdb\\9A\xc2u\x9d/g\xa6\x1aL\x84D\x1c\xab\xd9[<\x95\xd8\xee*\xfd'
        b'\x1a\xfe\xd5\xe0\xb8\xcd\xba\xe16|\x12*?\xcc6\x1d\xe2\x8c?\x18t\xbd\x81\xbf\x0b\xa5\xa2\xc7_l\xe9B\x9a\x91X}\x9f\x87\xcbf\x04r\x85U~\x8a\x02\xc4\xd92]\xaf\xbf\xec\x1c\xcc\x1c\xb3\x08\x02\xaew#\xba'
        b'O\x16\xee\r\xf0\xaeV\x13s\xefp\xa3\xfc\xab*)\x9a\xacV7K^\xa2\xcc\xecX\xaedDF2T[]e\x17\xf6\xe9\xdb\xf8\x10"\x14\x8c\x8c\xed\x8a\xe9\xeb\x0e9V\xde\xdbuj\xec\x97\xffU\x9fV\xc1\x11'
        b'\x08\xe1\xa1\xb8G\xa0F\xfa}\xb8\xd0>\x17\x14\xb93?t!5\t\xe1\xa3;\xc7.\x0c\xc5X\xadsQ~\xe1C\xba\x8a1\x1a\x9e`\xaf\xae\x97+\xfa_\x0e\x7f\x04t\xfc\xd6\r\xb7\xd5\xf6\x99\xcb\x041\x007\xae'
        b'\x80\xc0\x84\xff\xe6\xf0\x0c\x7f\x80;\xa1:C\xe6T{\xe1!\xf4\xf6\xe6F\xa5\xa8\xb1N\x98\xd0h\xddk\xe0\xae\xd3\xe4\x15\xa7\xf2\xbbc\x8eG\xdd\x826Y\x1d\x81H\xfc\xf5\xf9\xa0>\xac\xb2M\x04\x89G\x10\x83\xe6k'
        b'\x94$4XE\xf5\xee\xea\xbd\x85\r~\t\xce\xca\xcb\x0f\xa4FG\xb991\xa6\x1a\x9a\xfb\x0e\x8bp\xcf\x05\xa8\xbc4\xa6\xd8\x7f\xe3\x94\xf6\xfd`|\xe8\xbb|f)\xe1\xf4yh\x00\xc2"\xbc\xa0\x8e*L\x16\xb2\xb5'
        b'\xeb_\xe4\x90\xe3X\x1fY4\xd9\x87\xcf\rM\xed]\xfa\xf1vjwxzb\xdc\x87\xe9{\xdf%\x95"\x12\xad\x112Q*\xe1\xe78P\x10:\xba\x06\xadS=\x8eS\x08\x90\x03\x04`\xae\xe7\xda\xc8\xf0\xb1\xd0\xdd'
        b"\x7fb\xe4\xcb\xc6U\xa9\xa9p\xfd\xef\xcd\rSf\xdc_rcy\xb1\xdd\xe3w\x8b\xf6\x84:.\x1b\x15|\xe0\x1d\x1b\xf9'W\x1f\xac\xf6\xb8\x98+]\xa1\x92d\xac\xc8\xc3\xe8\x02}#;NF!\x8a\x03oZ\x89"
        b'\xc7A\xfb\xdcYg\x95~\xb2\x0e\xb2D,\xab\x97U\xe9\x06k\xe7m\xb5\x10\x15M3\x95r\xc6\xceU\xbf\xd0y\x00n\x9d\x87#[\x9c\xcc\x8d\xb6\xb3\xd4\x18\\\xa6f7\xf5\xd9\xa5l~{ \xd7\xdcr\xca\xbbb'
        b'\xe4\xe0\xbbB\xb2\xf0\xff\x1aTN\x94k\xb8 \xf1\x7fC\x95\xe2\xf3\x90WQJ%1\xb9Hc\x01Fn\xfc\xde\xdc\xf8S\x83\x8cS\x97@X\x9e\xc1I\x91;N/p\x07\xbc\x8b\x01\xa5yN_\x8eE\x8f\x0e@'
        b'@mr\x87p\x03)\xef\x8d\xa1~[4J\xbc\xa8vj\x8aU\t<\xb3\xdfr\xdb\xeb\x84,\x06\xf0GI-\xea\x11{\xa8vb\xb6\x12Y=Rh\xfe\xa8\xadE\xb1\x1f\xd2|Fp2\x02\x8f\x06\x94\x9cz<'
        b'\x15\xday\x18\xaeQ\xad\x8aQ3Y\xae\x93\xc5\\\x13|<<\x88\xbd\x8c\xe1\xb2\x11p\xc2\xe7\xb9\xdd\x82N0\xc0\xddE\x1d\xdc\xdc\xe3\x18i\xc6\xbf\x8aWY\xe3@tU\x9f\x1c(y\xfb\xcc\x01hz\x97\x97\xf2\x8c'
        b"\xa1f\xc8\x89'\xc7\x85\x18\x96gV\xec\x96T\xee\xac%i\xc6\xe8\xfc3l\xd6L#\xf55\x17hR\x7fS\xb8\xd3h\xa21\x16\xa0[zQ\x95\xee\xe0MK\xf1\x800AH\xe6\x04\xa2\xa3\x9a2\xbd\x90Z\x8a\xee"
        b"g\xc4\xab\xdb?\xd0\xbf2\xcf,hV\xf9\xd2\x85T\xcf\xca\xcdN^><f\xd4ux\xca\xb5\xb1m{Q|\xc0\xee\x94Id.\r\xc2\xf2\x0f\xa8tU\xee\x9f\x9e\xe7'\xb4E\xa41\xb4.\xc0\xea\xf7II\x8f"
        b'\xb5\t \xe7\xb3\xfa\xa2-E\x85G\x08\x00\x9315\xc4\xa4g\xe4\x00:}\x96\x1aV\xb2\xc4\xc2\x03\x1d\x95\x95\xbe,f$\xcdzQ8\x16g{$J\xf5NwU1r\x9ad\x8eQ\x1f\x85\xb4\x1cc\x924\xe7'
        b"\xa8\xa2D;-va\x8d'\xab\xdf\xd6(\xdcPl\x8c\x94\x1f\xe4\xdfq\xbed1n\x10\xa2g\x8c\xc5eE\xedsM\xcbiJ\x04{J\xb5q\\\x07\x1f-\x8dL(\xde\xdc\xcfDR\xb93\x1f\xef9$F\xcd"
        b'\x16\xacy\x80\x9d\x07d\x99\xba\xcb!\x18e4d\x13`[\xe1B\x06\xeb/\xe4\xc9\xaa\xe01\xf3m\x8b\xbb\x18\x0c.\xbc\x9a\xf3,G\x1c\xa89\xa1]\xc4\xda\xf1"\xb4\x19\xbb\xcbvn\xc7\xf5i\xac"oT\x05\x84'
        b'\xb4"\xf2\xfe\x8a\x8d\xeaT\xa0\xf8\x81\xc7\x88h\xe8\xe3\xea&(.zRK\xec\x0fw6\xde\xd5\xcfn$\x0c%\x061\x0c\x0f0\xdd\x1d7\x8bA\xc2\x0cm\x07s\xb6\t\xa6\xce\x07\x97_\xd8$\x0eM\x85\x0b\x90X'
        b'\xd1tV\xd1m\xc34n\x0e\x0b\x98K:\xbf\xc89\xa1%5%>\xb6\xa1\xa0\xcb\x01\xb8\x8c\xf4\xb3{\x98\x81\x0b\x1e\x86\xc3\x8e\x0e6$\x8f\xa0\x07\x80\xa3S\xe9-\x96\x81W\xe3\x07\xf4\x11\xf1&\xd9-\x0e7(j'
        b'*\xc4Ih\xfd\xf6\xfeCA c\x19\xe9\xdc\xa2a$\x83\xe2K\xf3\xe4-6\xfd\t\xa8_{\x99v;\xc9\xe0|\x05\x03jc\xa2P@6n&\x1a\x87/\x16\xd9\xac\x83\xf1\xf28\rD\xd2T\xf1\xcb\x87QP'
        b'C\xa6\x10S\xf2\xcc\x01\xddt\x83\x89\xcb\x13L\xa6\xba\xea\xdeH>\xf15\xc9\x84\xce\xaf\xe0\x85\x81\x15\x94\\\x97\xa0\xf5\xd6\x08E\x000u\xef\xc4\xd2\x03\x9d\xe9\r&Y\x84\x89\xa3\xf9x}\xad4\xa8\xa5I\x08\x08p'
        b'\xf2\xa0\xd0\xe51B\x14\x06XL\xe0\x1dE\xc4\x91F\x15\x7f\xadv\xc9Oo\xa2\xfe4\xd8RK\x16\x8c\xfcZ\xaav\xfa\xedS8\xf8\x9fO\xc8\xd7\x10\xf4\x0fEC\x1du\x01$Z\x02>\xe8\xae\xd6\xbd\xfa^\x91\x8b'
        b'\xd6\x7f8\xd8\rW\x1e^\xbbUg\x9f\x80_$s\xa6\xc7\xc0]\xd6K\xff\xa8\xb3\x7f\xc4\xaf\xa1\x84|NG\xac5d\x93L^\x9d\xe9K\xb3\xe9\xcc(\xc3G\x16\xb4\x0e\xa0C\x8a\xa4R\xef\x0b~M\xcc\x0c\xc2\xfd'
        b"\xe5\xf4\xe6\x8b\xc7\xe4~\x17y\xa7\x13v\x90\\\xe3\xbd\xf6\x8aN\r9\xbb '\xd0\x96\xc7\x05w\xa1\x9b_\xc3K\x93IM\x8f\x8f\xed\xf3\x9fP\xf5\x7f\xb7\xf2\xe0\xd6R]w|\x96\xf4\xdee\xbc\x7f\xaf\xb2I\x98<"
        b"\xf6\xf7\xfe\x85\xba\xba\x17\xd2M\xa1~\xbdNHx\xa6\xdd\xdfi\x05-\xe7\x82\x07\xea\x99pO\xd7\x8b'\xba\xd7\xa4\x1dd\x15\x8a\xfe*\xd9\xf5\x1a\xd1n\x99'\x93(\x8c\xd0dX\x83+\x18\x90Q&p9\x1c+\xb6"
        b'\xa7\xae\xe0\x807\x92\xe7\x8a\xe8U!\x014Hk\xf9bXV\xc0\x82\xbe\x8f\x1dI\xd3\xf1\xd6I:\x0e\x086\x0e\xaatC\x17d:\xd2\xdaP\xf8\x9e\xab,j\x192\x9a\xff\x9dw\xfaa\xc2\xe2K\xc6R>\x96\xa9'
        b'\x05\x99\xc6\x05\xc8@\xe2:8\xa7\xc0\x8c\x86\xc0\xbf\x11Z>\x8f\x8d\xe617\xb0\x08W\xe0baVy(-`\xf4:\xcb\xaf:\x92\x85!\x1b\xdd3V.\x96\xedS\x82)=\xf8\xde\xf5\xd2\r\x05K\xb7\x0f\xf2\xb2'
        b'_\xec\xbb\xb4\x04C\xa9I\x96\xa6\x8e\xcf`\xe2\x1cJu\x1bC\x19\xa8\x15;{\xb6\xa9\xd2\x7f\x03Bf\xca\xc7\x8f\x1fvJ \xc0\x00J)\x8f\xc6\xb2\xcb!\xfa)\xa0,W\x1d\x95\xa9(2\xc7\xd9M\x08\xdeNj'
        b'\xc2\xd24B\xa1\xd3\xc5\xa3t\xff\x8aP`\xcc\x11\x0b$\x81\xe9\xeb\x9e\x84\x071\x93\x85%\xa7\xbb\x85\x82\xf1o\xda\x83\x1ax\xa5#$\x9f\x98\xec\x80h\x94>\xfb\xa4hA\xa7\xaex\x9e\x19(\xa9\x7fE6\r\x90a'
        b' \xf4\x11Dz\x8d\x8c\t\x84\xca>\xa2\x054T\xba\x12&\x91\x8af\x03\xb4\xdcT\x928\x9dE\xf9WGm\xae\xd1\xa3\xe2_,t\xb5L\xf8H\xf1\xc556\xb78\xd1\x03`}\x8c\xeb\x80k\xca\xf4\xcc\x06]\x05'
        b"\t\x8af\x8b\x1e\x9d\x1e\x00\x9f\x8a\xfc\x15\xbb\x8a\xfd\x89^t\xd0t&\x96\x8a('_P\x99\x8az\xed\x19\xd8\xbd\xa1F2\x96\x03Lm\x9e\x02\xfc0k\xfe\xca\xe2tC\xdeU\xe1'\x02\x10\x89\xc3\x16\x18vR\x91"
        b"j\x01\x1bil\x99\xb0\x90<\xddC\xe5!\xa3\x98\xe8i\xe4\xed\xbcQ\x1etv\xcfu\xe7\x0e\xf0\xfb\xfc\xef\xe7\x827A'B\x17x\xe2u\x0czU\x96\xdf\x0f\x84\xb5\x1f\xd5\xe5\n\x84\xc7T\x90&8q\xb3\xe3\xef"
        b'\xa7\xef\xa4\x9e\x81\xb1\xc1\x17\x0f\xee\xa9\xb3B\x85:\x02\x00\xb6\x1f\xb9\xdd\x80j\xce\xb6\xed\x8co-\xecT\xf0\xb6\xf0\x7f3XK\xe8t\xf5 1\x14\xe7n\x82\x03\x04\xf8s?\x9f|\xb7\xee\xd5\xd4\x8b%\x15ro\xa1'
        b'ZI\xd6\xe2%fkeR\x1c\x13-\xec\x87P\x902@G\x8d\xdc\xa6H\xd5\xfb\xcb\xff\xd6\xbf\xb1]\xefu[4X\n\xdb\xac\xb6y\x1aq0\xe5\x9f\xea^zP\xbd,i\x8e@\xe5\xf9\xd1\x93q\x9a\xebN\x1a'
        b"\xf1\x93\x88)\xaa2\xcb%$\x88\xe6\xdc[f\xaa\x9a\x04Ze\x8d6'\xfc\xe0\x02'\xd8\xd8p\xf9\xc4lh-Z\x15\xae\xb4p\xf5 a\xc8\x8dV\xff|Is\xaf\xd1C\x02\xea\xebi\x17qy\x1f\xe3\xabIF"
        b'i\x9a\xcdE\xe9\xf3\xa6\x90*e+\x97\x89\xcd\x93\xce\xe3\xac\xc0\xd7\xbfrD\xb8\xd4t\xeb\xf3\xad\x1aK\x104w\xd3\x10\xa7\x84"IA\x04\xe5\xda\xcb2k\xc2\xd6\xf1\xb8]\xf0y\t:rt_\xcc\xc13E3'
        b"\xcd\x95\xca\xf2\xdb\x07\x8bt~\xaa\x0f\x1dn\xf3\xf0\x1dWA\xa1(\xd03X\xa5\xc3\nv\x82\xf8t:\x02(\xbd4K\xc0\xdd\x8cc\x12.6v'\x03[ixv\x98\xef\xfa\xcdsQd3\xd4'=\xe4\xf45"
        b'Ki\x01\xfa\xd0\x1e\xd9\xf0\x1e\x135\xf4G&\xae$g\xcd\x11\xff\x87=/ca9\xfbKL\xf7Q\xe2{\x18\xdc\x99\x0e\x16\xe0\xde\x12\x11\xcb\r\xd9#\xa5\xd8V6\xa4]\x87\xa2BV\xf0\x9e\x1a.\xa9\xeas*'
        b'\xa0\x16\xdb\xf6\xf6\x01a\xcb\xe3\xf5~\xc1\xcf7w\xa0\xb0\x1f\xa3\xb8\xb5?\x91\x13\xf9=\xd4O%\xc0\xde\x92\x91\xee\xaa\x0b>\xd6\xd9\xea\xd1xX\xea\xde\xdf\xd9\x99\x83\x1d\xc7\x08?/\xd6\x9f\xaayes\xfa<\xb5\xc2'
        b'\xe0\xafN\xa9m#\xa2-\xf5\xbc\x9at\x9b.@g\xee\xacjR\xb2\xaf\xd3{\x1d\x84\xe1+3 4I\x95\xa2\xba\xd4\xa7\xcd#0\xe5\xe4\x1dH\xaf5[\xe6\x17\xb8\xf2j\x1c\x1e\xdd\x93y\x1f"$\xbb;\x97\xa8'
        b'*\xb8\xa7\x02\xd5\x7f"Ig\x90\x02\x15\xbe\x0c\xd8\x80\x1f\xabF\x94z\xe87G\xbe\x0c\xe3~\xac\xcf\x9d\x9c\xc1Zw\xba\xea\xfe\x04\x9eZ\x03\xc8x\xb1\xcdJ\x9f\xe78\xf7\xfaV\xff\x99\xf3k\xdf\xd1\x01\xea\x90\xef\xde'
        b'\x90\x06\xb3e\x0fi\xe5REy\xf8\x8b\x11H\x1d_\xa4\x9b\xa5\x04\xac\xace\xf5]G\xfbO\x8f\xf6|\x08\x9f-\xc0\x1f\x15\xd7Q\x90\xb6\x82\r)B\xb1\\P\x07\xb8\x85\xfa\xd6f\x82\x8aJ\xb6\xc7Fr\xfa\xa0\x06'
        b'\x1a\x9f\x0el\xc1\xcb\xde\x19@m\x1fI\\r\x11\xa83[\xbd\xd5\x90\x85SV\xf4\xdf\x1a\xd6\xf1a\xf3j8\x7f\xf9\xb9\x1a\xf5\xfb\xe5\xfa\x0f\x16|s\xb5\xd6)n{e\x07\xa5 \xdf\xff\xcblh\x13\x96=KN'
        b"b\xd1W\x1b\xff\xeb\x04L\xd2x\xab\xda.\xa0\x83\x18\x0f\xced\xdd\xf7W\x01\x9a\x07})^\x1c\xa3,g\xd4k\xa4\xeb\xaa6\xae\x10q\x1f\xe3'\xfdL\xa4\x01\xe3v\xe2\xbf\xd0\x03k\xf8t\x9aS\xa8\xff\x83\xf7\x11"
        b'T\xac\xc1\x91^b\xe6\xc6\n\xed\xd4\xd31\xad\x0e\xb0\xa3\xea\x165\x89\xc2\xe8\xf5q\x81\x15\xca\xe4\x82lC\xe4Z\x1c\xe5s\xbd\xe4@\xb8\\\xc7\xf2\'%\xe7\xdc\x8e4\x9dNjb\xe0\xb6\xb7\x06\xdd\xbb\x9c"j\x9c'
        b"\xad\x1e'\xa1\xd6p8#\xf2\x7f\xdf\xd9\x03:\xd3u\xacu\x88M\xd1\x1d\x0b6\x8b[*-\x81\xcf\xc5Q ,\xe7\xd2eey\xc0\xc5s3\x95\xe2\x7f\x8e\x8e\xd7~T\x8ar\xa6Q\x16\xf2\xca\xd6\xe2\x84\x95\x99\xd1"
        b'>$\xcb<\xce\xff{\xff\xb3\xea\x11\x8f\xe3+Q\x8c\xf6\xec$\x88@R\xbc\xda\x00\xf9\r\xa4}\x9f\x83\xbaQ\xd99\x16\xb5^\xa5\xd4B\xdc\xf7\x93"\x85\x11\x88fQ\xadO\x8cO\xaeW\x07\x06Y#\xb6\xc1.4'
        b"tQK!\xbe\x04\x8d\x00i\x8e\xf7\xb0\xbc\xee\xa3]R\x1b<\x93\xa2r\x86\xa5m\x89\xd19\xcd\xe5\x14\xb3\x08E\xe8\xee\x07\x7f\xdb\xa0\xeb\x1f\xef\xa3*&S'\x0ft\xaew\xa5\x9b\x9c\xe3\xc0r\x01e<\xabJ\x1c"
        b'\xf3\x9f\xe0\xfbp\x17\xab\x8e^\x8e\xea\x16\x87\xbc\x1c\xd7\xe0n\x9e\x81\xda\xa9\xc7(\xa9\xd2\x9c\xc8\x93)\xeb\xb3+Go_\xe5\x9d\x8d\xf8\n\x14"\xe7.4\xe5\xd4\xdd\xc6\xbf\xc7\xdd\xff\x92U\xe9\x88\x1f\xc3\x842\x87\xc1'
        b'\x87\x1d\xcc\x1f.\x1eT~\x1b\x8c\xe8\x14\xf6R\\\xa3\xc2g\t\xa4\xbd\xea/++b\x8aa\xae*\x02\x88\xb3H5\xf0\xd8\xfa\x8aw5\xa2\xc8\x8cc\xe5\xb4P\x83\x7fB\x90F\xce\x8aC5pi\xb9U\xf10\x8d'
        b'E.\xe6\\\x02w0\xc8\x11\xab\xfdUU\x82\x88\xf7\xf8"\xdcS\xc0\xb6\xbd\xe8\x08vU\xa6lZP\xec{!\xef\xad\x8b\x18\xf4\xb7\xd910\x1f\x11*\xe7\'\xf7\x98* ,\xb4\xcem2H\x97\xec"aF\xd7'
        b'O\xde\xa2\x01\xac\x10\x91l\x1c\xa3r](?\xb6\xaaN\xf3\x10\xc1\x82n\xcc\xa9\x96C\xe6\xf2\xe2\x14\xdbf[\xf9\xe2\xe3\x8eS\xd7H\xdb.\x8aU\xe3\x8bX`\xcf\x17\xcfRvxw\xe0ZQ\xce\xeaecG\x00'
        b"\xa8\xe2\xd0(\x1b\x9d\x15M\x8eA\x10\xab\xf1\x97\x97\xc7\xd7\xb8\x83\xdf\xb7\xcal\x10\x00N1\xba\xc3\xe7z\x11\x8d\xe5\xf0\x80\xdc\x00\xe9.G\xc3\xb6;m\xc0O\xed\xe0qQ\xd5\x07'\x83\xbb\x8ea9\xd2\x91\x9d\xaeo"
        b'&\x13J9\xc0.\x0eK\xdb\xc5\xe3\xd5\xb3lr\xae]\x03\xba\xc9\x03\x82\x93\x05\x06Mh\x10\xb6"@J\x7f\x01K\x12\xfcS\xa9\xafCP\xadN\xc7\xf9\xacF\r\x17\xdcC\x17<S\xa5\xdf/K\xe2\xf6\xf6/|'
        b'*\xdaVK\x89Kn\x129O\xe2\xecH>\x9bmn\xe7C8\x93,T\x0b\xb5\x85\x00\xa3\xf0\xd8\x0f\x06\x11U \xde\x16o\xcd\x07\x17d\xd4\x11\x0b\xbdO\x92\xb6\x92\x94x\xedWiM\x05\xf3\xa9\xc9lw\x056'
        b'\x80\xcf\xad\xe9M\x92\x1cB\xf3K\xe4:\x9f\xad\x01}\xd6wZ}\xf9\x84\x18_\xff9 \xe5\r/I/M:y\xea$\x98\xa6e\xc8\xa1\xef\x8f\xe2c\x88\x1f4?\xe4\x8a-Z\x7f2\xde\x1e\xcdUS\xee\xcet'
        b'\x1e\x92#\x87?\xe2=\x196\ta\xc6\xca{\xf8{\xf2e\xa5_y\x8aDL\xfbgc\xcfa8C\x15\xdf\x1e\x18C\x1e\xd7\x03\xcb\xcb\x85\xfej\xf0qQ\xc7*\x81\xdb\xe0G\xf0\xcfC\xfa\x83\xa3Z\xa2\x0b \xe8'
        b'b\x93\xd0\x18Q\x0e\xc9\x93_"\x02\x93r\xb1\xf2F\xcf\xb8\xbe?\x1c\x1e\x91>\xfa\x13\xc0m\xb27\xd24\x0e\x8c\x9dQ;\xc4\x8d\xfd\xc5\xe9\t\\z\x87\xde4\x83Y\xe6\x1a_y1P\xf6\x05LoP\xe4\xe3-'
        b'\x8b@\xf8\xa9U\x8f\x0b\xd5\xe7\x84\x9f\x17T\xd3\xe5?\xbb\x8a\x8a\x7fC\xfa"K4^\xfa\xe7\xf3:\xd0\x9fzf\x88\xc2:?\x94\x8cjJd3\xe8/\xdd\xc9\x05\xaf\xa8\x1a\xb2\xb1\xc9c\x83\x1a\xdc\n\xb9\xa4\xd2\xfd'
        b"\xce[n\x96\x06\x1c@T\x9d\x1b\x82\x93\x10e\xeb\xaf\xa6\xe5\xca]a\x96glR\x15s\xc2\xaa\x91\x99m\x89L;>}\xb0{\x8a\x93.\x8f\x80\xabn\x97\x15\xb9w'\xf1\x8e\x87\x12\x05\x12\xec\xd3\xbe\x15L\xa7\xa3"
        b'\xceu6C\xa0\x8d\xb7\xe9j\xed\x15-g\xc5Z\x08mz\xcd(C_\x8319\x1c\xf5\xfeFQAf\x16\xd3\xd7\x93\x87[\x82\xa6z\xcd\xeac\xd8@\xb3\xdd\x82\xdb\xb9\xc5$r\x93\xaeWy\xafE\xa9\xd9\x832'
        b'*)\x04\xfc\nF\x8cj\x98Q\xcf\xfe\xb2\x0fF\xb1t\x15\xf9\x1b\xea\\\xf7<\xe3x<\xf0=\xebK\xfe\xb0\xf4\xd6\x89\xf6\xa3&\x7f\xf3K\x01\x1dx\x92\xe6\x8a\xe8E4>\xef_\xdaSV\xe7]\xe5\x04\x1e\xeb\xd3'
        b'u\xaa;\x1bi\xe7\xe6\xdcHW\xfc\xd9\x08\xca\xda\x8d\xa0?\x0b\xdc\x86\xd16\xfe\xddud\xad\x19\xa0\x9b%:\x90\x0e\xaa\xd9Re\xda\xb0\x9d\x82\x00]\xd9C \x0c\xe5\x9er\xd4\x1e\xd1o\x93\xa5\xed\x93\xdd\xa91\xeb'
        b'\xee\xb463\xad\xbeK`\x8c\x11\xf4\xf8\xc7\x19\x99lK\x8e\x82{:<\xe1o\xba\xbd\xa2S]\x84\\\x9b\xe5\x0cs7!\xf4r\x0f\xf1\x9bXsX\x1bK\xb3\xa7\x86e\x9b\x8c\xf3F\xda!\x1d\xe2\xb0\x00\xce\x9e\xb3'
        b"\x9b\xa8\xac\xa4W\xa4\x88\xf4\xa5\t\xd6\xfb<h]\x17\x94'\n<[\xfak2\xef\xa2\x8a\x81\xe2\x9fW\xb3z\xb0H\x05A\x05i<A\x89\xf3%\x0cE$\x9be\x9bo\x1er\xc3\x05BW;\xbb\x99/`\xc9P"
        b'w[\xfcB\xda\xd3#x\xe2\xf3z\x8bc\nG/;_\xb9\x90I\xde\xa1Kq6\x0f\x96s\xc7\xdb\x16\xa7\xb9\xcc\x15Y\xffV\xca|u\x97xB\xc3LV\xa8\x8bi\x9d\xc4VO\xf2\xc3\xd4\x98L\xae\x1b{2'
        b'\xed\xb4\xcb|Q\xf9\xc9\x12\x9ef\r\x8e\xc3\xee\xf0\x1a\x0b4Y\xe1e\x1b\\\x03 \xac%\xeb\x05\xbf\xd3\xce\x82\xa5\xfc\x9d\x19$\xdd\xa5\x06\xf9\xa9\x90B~*;6R~\x9d\xe1\n\xbc<k\x81\x9c|\xd8\xb1\xcd\xe8'
        b'`M\xe38>\x0b\x86"\xe8\xa5m\x07\x89\xef\xef\x07\xaaS\xe4\xa4\x0bK\xdeA(\x87m\xe3\xe7\xa8\xc3q\xbcQ\x01\x97\x7f>\xf2<"~I\xe0jl\xe9\x9d<\'\xc3\x9d\x85\xbe\xb8C\xb2\xbbH*M9Ak'
        b'b+#\x8b\xe5Y}\x8e\x19\xe2\xa5o\xb1\x13\xe7\x01\xec\x89X\xb1\xfdHF)\xd0\xfc\x88l\x06\xf5\x07\xfd\xb4\xa8P\xd8\x0b\\\x05\x03o\xe5\x0f\xcb\x12V`\xeeV\xd3t\xd2\x85"\xae\xa3\xe4sM\xed\x92R\xec\xd2'
        b'\x07\xe9\x13\xe6c\xc5>7\xa7\x17\xca\xfc\x92\xed\xcd\x0f\xb47\x17\xa8\xc0\xe1\x89\xd8\x02\xb5k\xee\xebs\xc6|\xe6pxd*\xc2\x0c\x05\xf7\xb1\xf6;\xc8\x19vm\x95\x18\xb3I\xcf\x95\xfb\n\xb6JH\x1e\xee\x15#"'
        b'Z\xca\xf2\xde\xc4\x1e\x8a G\xedDFW\x97\xb2\xae\x93`\rT\xff\xfc\xf8\x16\x05q\x0b\xf7\xb4T\xf5\x93\xcfx\x14\x1c\x87\xf2\xc2"\xca-m\xc6\x9f\x87h`\xf9fm`\x04\xd3\xf8\xe4\x83>\xa8\xee?\x06\xe9\x04'
        b'\xdf4oU\xf1;\x8cZtl\xf7\xfd\xddZ\xe4\xe0\xc6\xfc\xc7\xe8H\x1aP\x9f+Ej95\'T\x16\xe4\xd9a\xee\x04y\x9d+\xc5=6\xdd\xff`\x8c"\x14;\xfb\xdf\x04\xfa\x0c\x95\xf5n\xf5\xcba\xda\x07q'
        b'\x03\x1c\xef\x9arq3\x96\xcc~\xc0fh\xd3y\x8f\xabb@\xca\xdbI\xfc\xdf\xbc|\xaa#\x06c\xc7\x02}B\xf1"\xdd_\xd4\x00\x99\xfa\x01\x81\xa8\x14g\x87i\x14\x93=]\xf0\x8e\x11\xa5\xea\x9d\x8cn\xe4\xdcb'
        b"\xdd\xfd\xda/\x83Z\x88\x88\x9b\x89;O\xa7V\xf9\xab\x01\xbd\xe6\xf9\x80J\x8b\xc1\xde\xed\x9bH\x0b\x8a\xd1\t\x8a'z{\xfe\x95\x11\xceVK\x87q\t\x81\xe7\xd5\xf5k\xf1\xa6\xa0i\x89[\xeb\xef\xb8\xefJ\x1f\x88\xff"
        b"X\x0e\x1e\x87V\x15\x12\x1b\xc8\xa0\xbd\t\x8f\x1c\xe2\xd5\xea\x8a\x80\xe4\x990\x9do\x93z9\xcbm\x15*\xbc\xdb\xf7\x07\xcc\x8e\x19\xe3\x04\xc6\xf9&\x02\xd2\xc5\x1f\xa7\xbap>'\xb0\x96\xe5\xf5\x84\xab\xc2y$sg\\"
        b"\xbev\xc7\xcf\xd9\xad\xe6\n<O'\xcd4\x8e\xefnpU\x9c\xbe\xcbM\xe8\xecr\xda\xfa\xbd\x81I\xe2U\x11\x8b\xb9\xb7|\xa3\n\xb6Z3\xf2B\x19\x04\x08%\xf0\x83\x99,\x84\xbd\xe8\x90\x1e|\x91?\xf3\xf3i6"
        b'_\xccU\n\x1a\x97\xbf\xbc\xec\x88\xf6\x86\x87\x97Q\xddK\x06WQ6B\x9d\x9b|\xc5\xf2\x19\x0fv\xbd\x8e\x10\x9c\x01\xf2\xefgP\xf8\xa9\x06\xa6\x8b\xe6!U{f\xd7\xde8\x87\xa0\xf7px>T\x9dyl\xf0\xbf'
        b'\x00:#\x10\xb9PA.4%\xe5{\x94c\xb3B\x1f8\x01\xf2\xb3\xf2\x0c$\xf3\xc1\xfbQ\xd4K\xec\xef\x92\xe6\x91b\x90\xac\x9d\x82.D\xb1\xc6\xc9\x16\x1cS\xa9V<DA\xa6Qaq8\xec\xads$ |'
        b'\x92\xc9Zs\xd6Q\xdbR\x19\xcd\xf36\x0fz\x8f\x9c\xfc\x1e\x86\'\x9e\xaeBu\x9c\xbb|"8\xfa\xc2Q\xcea\x82=\xac\xa0\x96\xfeZ\xd1f\x86u\xff\xc9\xa7>\xf1\xdb\x88\x9a%\xe4\xcf\x11dc\xf11_\x94\xd7'
        b'\x86\x86\xbc\x8e\xf8\x13_\xb8\xa6\x9a\xecu\x865:\x07%\x06@~\xfb\x7f\xdf\xa5\xeb\xadV\xb3h\xafv\xa9 \x1aU\xd9\x19\xd2\x18\x17\xba\x82 \xec\xb80\xeb)\xdb\xad\x14\x80\xbb\x00\x8dE\xaaKTN\xe1\xa2%\x7f'
        b'\xed\xadd\xb5h\xce\x01\xc3|\x07\xcbC\xeb\xc4=\x9aXNH\xdc\xac\x1c\xf5!\xee\xed\xd0K\xa5.\xfa\xf2\x9c{\xf1\x1f\x1fAZ\xed\x832\x8bA\x00\r\xe4\x17\xb6Xs\x08l*\xc2\xab\x88\xd62\x14\x04\x86\xcf\xf7'
        b's4\xbe\x07\t\xa4\x0e\xd0\x16\x8e8\x84U\x1d\xb6\xd1\x05f8o\xc7\x0f\x0c\xd6\xe7\xd2/lW\xa1\x87\xbe\x19}en\xd9\xb0\xde\x1b\xea%\x83\xf5Y\xbd|\x88\xa8)vHab"\xab\xffewm)7&G'
        b"\x9d\x10\x9b\xb7Z\xd0)\xf4\xaeZPq\x96j#\xf8X\x93\xf0\x17G\xea\x0f\x88Q\x8aBhX\x07*'\xbfmp\x81\xc5\xffP\xf8\xfdo\x83'\xf3>\x895\xa9\xa3\xd6\x87mD\x87PC\xed}'\xec\x99)'"
        b'\xd3\x17I]\xdd%\x07\xacj\x85\xde\xdd\x18\xc5I\xf2\xb5\xb8\x8a&\xe8\xbe\x1f\xe1\x1c\'"\xbd"E\xa4V\xe7<\xcc\xca\xd0\xbc"\xa5o\xc1\x95\x16\xe7\xf1yj\x97h\x1fVT\x1e\x13\xdd\x991$\xa8\x04\xc9\xcf\x9e'
        b'\xb7\xbf8\x12:\xf7\xec\xa6iP\x99\xf7\xb9\x10\x9b\x14\x8a\xe8`9pC\xc2\xf1|+\\4\xf9\xf5\x01\x88=\xab\xe0\xa0\xad\x90hvo\x916\xed\x12\xa6!\xe7\x83\xe9\x04\xec\xa6\xfa\x0c\x17\x8e)\x9apC%q|'
        b'\xe7U+h\x99\x0bF6=\xb4\xd1\xfa\xfaE\x8d\xf8\xeb\x12\x90h\r3I\n2S\xe5{\xb3\xa6:~\xfaCV\xeebn\x87\xba*\x06X\xf9\xdc\xe9\xa2\x04\t\x11\xaf\x91\xae\xf1s\x9c\xf6\x07m\\\xd9KT0'
        b'\x01\xb7t\xce\xcdB\xe1\x01W\xd4?Z\x92\xd3\xea\xb36l\xbf\xdd}\xbb \xa6\x8f#\x19.\x0f\x83\x19\xd7\x08P\x16\x0b\xdb\xdfq\xaeV\xe0\xe9\x8b\x9c<\xa2\x1e\xcb\x1b}Y#\x13g)\x99V\xd2\xc4\x88Wz*'
        b'\xcd\xb9\xff!\xac\x1f\xa5\xfeN\xccg\xf1=\x17\xde\xc6\xf4\xb29\x88\xdd\xde\x1e!\xc8\x14\xd5@k9c \x14\nq1%\xc3\xd5\xb9\x91l\x825\xfe\xa3\x02\x0c\xed\xc5gT2\xbd\xc9I\x10\xeet_\xbb[\xb9\xfd'
        b'\xa3\x8bN\xeaE\x94\xae\x9a;\xa0?j\x077-\x13|\to)\xc7\x1d\xde\\7y\x03\xd1Y\xba\xc0\x10\x97\xec\xce\xb2N\xaa\xfc_\x7f\xeb\xb0\xbd\xdb\xca\xb6I\xff\xc5\x95\xf6/\xa2\x05\xb9\x08HN\xd1\x8eS]\x16'
        b'@R\x9bfVx\xd9I\xb8*G\xe8\x18\x9e\xa5\xaf\xe7\x93;1\xeb\xa0q\x0b\xf5\x9b\x88w@i\x11\xf0\xa8\x00\xd5\xf0P\xc0\xd7\xbb\x80\x8fb%\xf9\xd9\x80\x83r`z\x01\xc1\xab\xe4#G\x9f\x08\x96\x9d6-\xd0'
        b'\xc0\xa7\x84\x01\x1f\t\x06@\xd0\xa9\xd5cr+\xf2\x0f\xfb\x9a\xba#\xcb\xb0\xf3\x87f\xa5\xa7jk\x13\x01]K\xbc|\x90M?P\x00\x9f\x9a\x96\xd4r\x04\xe6K\n\xc3\xf8\xf8T\x13i\xb7_\x81\x1eH\xa1/\x12r'
        b'\x82\x8f\xb8\xb5\xc3\xb0:\xd0\x0b\x0f\x95\x0c\xf5{\xc8\x9b\xe9\xcd\xde$\xd2\x8d\xe5\x9c\x1b\x8b=j\x0c6E\xc3\\"q\xfc\x893F\xece\xc6U\xadC\xc2\x7f\x00=zQ2\xf9\xfe\x1c/ .&\xe0\nb/\x0e'
        b"}\xfc\xeb\xda\x9c\xeewk\xe3x*!\x93_\x11\x91\xa2n$f\xe1l\xd7Nu\x12j8\x7fZ\xce\x9d|\xe7-\x05\xd6\xad\xa7'\x92\xdf\\/\x1a9\x08J\xcf[\xeeh\xf8\xa4\xb3\xd8&\xa2a\x96\x00\xb1\xb8T"
        b'\x88\x15=\xd2\xc1\x7f\x97?\x10\x92\xefe\x91 \x08v\x8ch\xc0\xf8FA\x867\x9020(cF\xb7\x1d\\\xdd{"\xdew\x1b3\nQq\xb0\x90\xb07\x14\x1fj\xfb\xeb\xf7\xf47\xcd_Y?\x03\x0b\xadQ\xdd'
        b'\xb2a\xc1(\xba\xe4\xa2"\x8cD\xf2v3sj\xb4\x8f[\x98\xe7\xcd\xd6\x95H01e0u\x0b\x9e )\xe6~\xd0\x99\xc7nm\xa9\xc0\x95K=]\xa1Z\x85se>Q\xb0\x9a\x85%\xdb\xe4+\x1a\xf5\xceg'
        b'I\xaa\\&\xda\t\xcb#\xc6l\x15Sc\x10\x8a%Kk\x1af\x0btTM3\xc8\xcc\xe0\x8d\x11\x1ck3?5?\xde\xdc\xcfL\xb4\x0f\x84\xac<G\xec&8\x8e6\xe9,"\x01\x9a\x9eB\xc8:\r\x7f\xe0\xb4'
        b'UwM\x11 \xe5\x1d\xdb\x8b\xc2\xa8(\x14d\xab\xfe\x1dA\n_`\x10\xaa\xf9\xe9\xdb\xcbi\xcc\xc3\x8a\xd2\xa7+<\xb9\xaa\xb6\xd7\x08\x82`K\xc1W)`v\xf4u\x1e\xc6\xb9\xc2O`\x1a\xbeCQ\x11\xa9\x0e\xeb'
        b'\xff\xfa\xc4\xb4\xaa\x7fS\xebpR\x81\'\xd2\xfe\xdf\x93\x9e\xa0\xc0"I\x06f\x0fP1%\x9c\xe9}\x8e\x91o\xcc\xba(\xfa\xfdqaS\xc8}$\xca\xaf\xfc/\xda{Q1\x10\xd55\xc6\x13\xb2\xf5)\x8bS\xaao'
        b'\x1dr&I\xf6&\x08\xaa\xfd\xbb\x16\x072\xd1m\xde\xa8f\x11,)\x8d\x1e\x16X\x04\x92\xcd\xbd_\t\x96\xf2\xdf\x9f\x87\x9d\xec\xa6\xb8\x81?X\x13z\xf7\x81\xe7\xcf\xa0\xb4\x99`&A\x7f\x07\x8d\x18\xae3\x13<\xd8'
        b'\xa8w\x92_\x96\xb3\x95\xc2\x8f\xbb\x97\r\x92f\x1a\xe7\xb3i\xd0p\x1e\xc6\xf1)\xfa\xd5\xad-\xb4|\x0f+q\xf4t\xc1i\xb9\xda\xfd\xf2g\x9b\xa0\x90\r\xdd\x8b\x9en\xf3\x8f\x1bh$\xcc\xeal\xe9BM\xeeeG'
        b'\xca%\x08\x16\xe4_\x96\xd9\xbb\x12-\xb1\xf2\xc5)"\x14?\xa2\xd1(\x87\xca\xa2Y\x8cb!h\t\xd9\xfa\xe8{\xa4c\xa0y\xbe\xeb\xd9\xafWMs`\x190\x1d\xc9\x87E}\xe6\xdf\xf8>\xb2\xe4\xa9\\\xb5\xf3\xcf'
        b'%\xcf\t\x04\xbe\x03\xc4|&\x80\xdc\xc8\xb6E\x89\xe3\xc8\x08=PB\xc5\x1e(K\x96\x01\xb1\x85%\xcaY\xfe\x92\xc6\xff\xf2M\x06\x99\x9b\x9f0 \xdd\x8eDL5p\x0c\xc8V=\x00\xe8\x87c\x12,3\xde\x1f\xbf'
        b'G\xa8\nY\xae\x88\xb2\x137\xea\x86\x87\xf1\xf3BO\xd1\xfa\x9c\x01\xd9$\x9b\xbb\xe7\x8c\xe7\xae|\xb4J\xcdC\x0eSd\xf4\xbftorX\xd7\x1a\xaa=\x90\xb8\x98\x1dk7!\xd1Y\x87\xbc\x8e\x17\xd4\x85p/\x1b'
        b'\t\xc6E\x96!I\x8a\x03n\x8e\x92\xd3\xea\x94\x9a+Cv!\xf8\xbc\xfb\\\x05\xd07\xd1\xa1\xd9\xa9\x1b\xbbK\x9fi^\xdblz%N\x93\x99\xa1{\xfd\x8f\xbe\xb9\xa2\x9f\x9bnb\x17\xba\xdd\x86\xbd\x17)\x0f\x95\x0f'
        b'\xde\x93\xad@\xbd\x99\x02\x0c4\xf3Y\xcf\xf1\xcf\xd5-\xa6\xd6!\xfd\xa8O\xa2\xb0\xb75\xe4\xc9\x0b\xe9f\xc0\xfe\x03|\xc7"f\xcb\xdb+\x1b\xa0XO\x03H\x1d\xdb\x12\xae\x8e\x19\xa3\xd0L\x9d\xef\x06M\xc2&\x18~'
        b'\xf4\xe0\xd4\xd0\xe5\xf1Y\x11\xbe+,N!\xca\xe8\xf0!\x85\x996\x9e\x1bL\x8e\xa1\xbe0\xac\xff5\xc6\x99\x1ay\xc9\x8e\x02\xe8\xf6\xde\x8ecM\x8e\xec\x8a\x10M\xeb\xd0\xe5\xd2\xb0-\x974z\xcaz\x1b4\x87k1'
        b"\xb0\xd8\xf3] q\xabe5\xc0\x9c\xb1\xf16\x01\xa2\r<\xc2\xa8W\xffJ`\r\x00\x9e\xaa\x97\xb6\x89'\xb0\x19\x02S\x9f\x1d\\\x1cB]\x05\xa6t\\ !\x92<\x0b/{b\x02b'\x84HLC\xeb\xb57"
        b'\xbc\x8ed\xb7\xd8\x1a\x87\xf0\xf8\xa3N@\x10Z\xa1\x8b\x89y\xd7\xaf\xf1p9\x05\x1e\xf8\xf9e\xb7K\xa6+l\xb68\x82\xf8\x82\xb0\x05\x0e\xd8\x16x[\xad\xcbZ\xc0\xe6jq\x8f\xa5F\x00R.v\xc9\xce\xf6nV'
        b'\xf6^o7\x16If\xb21\xb0Z\x9c\xdbQ4\x95!?#\x10\xc7n\xff\xd9\xbc\xe3 \xc0\x87\xbb\x18"\xe0\xd6\xd4\xbb\x15\x80\x91\xf5\xe3r\xfa\xb2\n\x14~\xc7P\x93\xab\xc1t\x8e\xdf[\xfa\xd7\xfa\x03u\xc1\xea\xc6'
        b'*z\xf8\xe5\x12\xd4\xab\x9a I\xdab\xe1\xb3\xe1;;\x1d&,\xe0\x82lZ/60\x88/L\xd7Y\xb0oX\xa8\xed\xcc)\xf9{\xcb\x1e\x11\x11\x10\xc1\x13\xdc\\\x08\xcd\x9e\xba"X@R\x1b\x06b\xb8\xee\xf3'
        b'\xdd8\x9d\x97%c\xaaj\xf7{\x05\xde\xb7!\x067\xad\xe9~\xe9\xbb\x95p\xfa\xbb\x83\xa3\x1a/\x1d{\x8d%\xd5l\x8b\xa884=\x12\xd8\x1a\x9d\x11\xf6X\x02%\x11\xdfY\xc2v\xe4\r\x13*9\x8b\xb8\xc71S'
        b"$\xb0f[\xfe\xd7\x1ag\x91u8\x13!\x1a\x13\xdb\xad\xb2+\xac\xe8\x80\x90mD\x16\xb9'\xb0gj\xf9K\x7f\xe16\xcdo;\x955\xe5\xc9\x1a\xf8\xe0\x17\xd5\xc4\xbf\xc4\xe0k\xa52\xdf\x00F\xd9\x7f>J\x19\x9f"
        b'q\x9b4\x9c\xf54\xf2L\xae\xcf\xc8$\xe0R\x18Lr\x1a\nE\xc9\x0e%\x03\x88\xa0[\x98\xda\x83|uH\xa4\xc3Q\x0b\r\xc5\x9e:^6L\xf40\xb8m\xe1i\x14uO\xb9\xefR\x01\xf5\x95\xe0\x8dv>\xcd'
        b'\xb3<u\x97\xadI_Z\xfeH\x05\xf7\x0fg`\xc4\x8a\xb4\xa4\xb1\xdd*\x98\xaf\xe0a?\x18\xf3\x17\xdd\xba<\xf7i<\xa1M\xec\x17\xc1v+\xbd\x13R\xb9\xc3\x8f\xfbH/\xf5\xcf\xffh\xdfdu8\xfd\x1f\x18\x9f'
        b'\xda|#\xcd}6+\xfd\x8c"\xb6\xf9\xcaa\xc5\x1d\x84\xce:`\\\x07_\xb0]\xa8\xfd\xb1q\x01O\xbf\xdb\x84\xf8\x19\x11\xa4P\xd4\xc2\xfc\x06\x83\x94\x890\xb8\x81M\x8d<\n\xcb\x84v\x1c?e~ e\x13\xcc'
        b'Exf\xc3\xf2\x82\x95\xcbi\x9e\\\xf3])\x01@?\xd1\xff\x01\xb18A\xf5\xd5{f\xdb\r)\x07\x86\xdc\xd0\x84\x82\xae\x83\x08\x0b=\x9c\xde\xa4]l\xc8 }\x1bS\xb4\xdbTvGf\xc5\xd5s\xcbxf\xed'
        b'\xff\xfb{&\xa9\xf3\x03\xaf\xd1\x18\t\xf3\x19P\xa9{qc\x0b\xe3:\x92\x11\x91\x05\x11\xa2p@\n\x18O\xd5\xa7\x80\xc5+\x05u\x95\xdc5\xc7BQ?\x19\xd2\x8bB\xed\x82r\xe0\x94\x87=9\xde!!j0\xd5'
        b"\xa1;\xe97\xccA\xe2y\xc1\xc2\xae\xc8\x80\x88\x99\xb7\xf3{\x04\xae-$\xac\xf0W\x03\x99\xa2'%\xc3\x91j/\xa0\xdb#d\xddu\x90\x01\x03\x82\x89\xb4\xd7\xed\xbd^\xf7:R\xf3\xf3\x0bs2\x94]\x99J\xed\n"
        b'\xe7.\xb9\xdaX\x17\xc7\xb9}\xdc\xe5z/\x86T\xda\xdd0A\xb2}\xf1O>nMS\x01\xff\xde\xd5\x02S\x8f{\xbcTP\xedt\x9c\xd42\x9e\x84\xa4\t\xa4\xba\xd4\xc2jF\xf7\x13\xfd\x08\xf7\x16\xd5\xb3\x8f\xb5\xfa'
        b'\x15\xd7\x88OK\x96\x0e=\xf3\x9c\x17P\x02\x9d\x19\x15\xb15\x83\x1b\xf6e\x1d2\x03j\x03\xa7;\xc3\xce\xb5o\x00\xdah\xe0\x081v\xe4\x9b\x1d\x1d$\x00\xad\xa1^\xc9\xc6Q:\x98\xf05m\x9f-\xf7\xb7\xa8ID'
        b'\xe0\xef@\x96\x961u\xd5\xf74O~\x1a>\x82\xc2\xca\xe4+.ux\x1c\x1f\xd0N\xcf\x93y\r:\x1a\\\x98\xa6cj\x18nP\x0e\x14\x13v\xe9\xfb8\xc88l\xa3\xdbF\xe0\x9b\xeb\x0c\xf3\xb7\xc3u(\xec\xa0'
        b'u\xf8\x1e\x9fS\x83\xf4\x19R2} \x0e\xee\xb5\x01\xd3\x95\xe9\xf7\x81\x96\x8cx\xcc\x86$+\x82\xe4P\xb1\x07)\xde7J]+\xe7\t\xa2\x19\xce\xd0Ro\xae\xc2\xc9\xc26\xe5\x01I.\xab\n\x1f\x1a{\x9f\xe3K'
        b'^\xa9\x1a;\x1dis\xe4a\x0c\xaa\x18tW3!\x9d+\x84\x83l\xfa\xfb>\xf1a-\x06\xdf\x87\xcbs8\x8a\x08\x16,\xce\x96\x17\xfb\x88\x9e\xec\x81\x9cr\x9e\xbd\x0cTl\x18vp\xeb\xee\xc4\x01R\x88\xb1Y+'
        b'f<\x8c C\x0b\xbb\x92\tN\xa7\x8bV4"\x91\xff\x18`\x10\x0c\x07\xffP\x98<\x8d\x06\x9b\x1b T\xf5\x1e\x1e\xf4\xbb\x18\xb3\x8f\xaeD\xa5\xca,axa`8c\x13II\xffW\x10\xc2gjQ0\xeb;'
        b'!\x1bt\xe3\xa9\x1e\x0f\x1b\xebl\x89Dn\x81]\xacZ\xa6V\xfb\x10\xe9h\x8c\x1b\xc0 n\x9d\x0f\xdc\x07\xb0\xab\x1c>q\x7f\xc2\xa1%3r\x97\xd3\x87["%\x10_\xf4r\xf5e=\xda\xc0\xdfT \xf4@\x9e'
        b"~Z\xde\xe40s\x9c\x8f\xb9\x18\x12\xf0W9<\xb9)\x1e\xe0(\xc5 \x95IT4\x0c\xbe\xdbQ\xda\xe9\xa5(q\xa1ZX\xb6\x9bu\x7f\x89b\xbfU\x01\xf5\xc2'\x0e\xcd\xc8\x99k\xcd\x88\x04\x92\xc47\xfe[L"
        b'\xa9l\x94-t\x81\\h\r\xd3t\xce\xd2V\x1e\x8a2:\xf8=\x96\x0b\x00\x88\x85<\x0cj\x0f\xc4\xc5/\xcd\x8a\x9e\x0f\x08\x87~\x08e\x8b\xa6\xa0"\xf1\xc5\x9e\x0e\x07\x08\xf8\x12C\xf9\xf3\x9aF\x80\xc25,\xea\xa8'
        b"\xca\xb5f\xef%/\xdb\xc6\xc8\x92m\x10(\xe8y^\x0c\x98\xe0\x12\x85E\rm\x00}p)\x0f\x17\xa60\xca\x17q\x89\x9a^\r\xc9/\x0b\xfdf'\xe4\x00\x85v\xe5y\xfa\xcd7\x91\x12\xa0\x98d 8\xda\xc3v"
        b"\xf0i\xb7\xc7\xbe\xb0yC6\xab\xee_\xc7\x0b\xc5\xa4\x1a'\x12\xd2\x19\x1f\xc9\x03\xce\xba\x08\xb1\x1a\\\x81\xb1\x12\x17M?\xc3lp\x03\xd3\xd0\r\x8fl\xa0GW\xfc\xbe4\x99\xc7\xb9\xf7Z\x17\xb1`!\x90\x01\xac?"
        b'\x8d\xb5\t\xab/\xe4\x1f\xe8\xa9H\xd4\x14,"\xd1\x0e93}\xbc`f\x86\x90".\xa2v{i\xfe\x87vo\x0e\xe4W\xc4\xe1\xa7\x06\xd4\x7f\xa4\xb5:\x86\xe0\x0f\xa2\x0b\xaaF\x8bP\xadJ\x1d\x84\xaeiu\xf0W'
        b'\x8e\x134\xc1\x0e\x18o\x9d\xb2\xb4\xc2<\x88Vv\x9e\xde\xca\xd6\x80\xe3\x04A\xf5\x88m\xebS\xd1\x03\xbf\x83\xd1\x90^7\x8aJ\x88#JL\xe8\xd1~x\x87\xaa7\x14\xb7\xd0\x16\x00\x0b\x9a\x8bl\xf1#\x18\xbb\x14\xba'
        b'\x07%^\x14\x7f\xc7\x85\xc1\x1eT\xb0\xbe\x82h\x8crj\xa7\x7f\x80\xb3\x9b\xc9D\xb9?\x7f\\NU\x16\x8fp\xda\x00\xf8\xf01\xc5N\x0eq\x1e\xc6<ck\xe6>C\xadS\xd6\xf9\xc7\xbf\xd2C5?q/\x85\x06'
        b')2\xa9\xaf\xe5"po\x98\xb4\x8c\x1a\x9d\x8c\x9c\xe0\xea\x1a\xd2x\xff~\xfbI\xb9\xa5>\xd9/|\x81\x95\xabi\xff\x11\xb3\x93\xfa\x0eGj\x8c!\xd2\x03O2t6\xb1Qne.\xa3I\xb1\xa9\xcc8\x81r1'
        b'r\x99K\x90Q0Q\x87\xde`\xbb&\x02\xda\x00vZ\x051\xc3=\x1f\xf3\xb4 \xd9r\x00\xdf\xf3,N\xb4\x17\x1c\x0b~*\xd4\x10\x0fM\xa7\xeb\xe3\xe2\xd3\xd1~8O\xa9\xe7\xa7\xfd"\xc7\\\xccHe>QT'
        b'\xd9\xf1\xf7\x082\xd0?\xd2\xcd0-P\xf4\x14\xd6\xf0\xb6\xff\xfeBa\xeb\xe29\xbd\xfdc\xe0\xad?\xe9\xf0\xcd7\x17\xc9Z[\xe6\xfeDi\xce\xbbR\xb8\x98\x16\xd6\x9e\xd5r_\x0c\xc8p8\xe3zo\xa2\x8e\x7f\x84'
        b"\x92\x11@\xeaL\x0b\xa4\x01\xc4H\xa1\xa2\xab|\xfa\x9a\xa4;s\xc8/\xb7\xeb\xb8*=\xb4Y\x0c,\x94\xe8\x80\x15'a\x9c89|\xecX\n~6\n9\xff;4B\xbe-\xab\xe7Pl<\xd4\xe2\xf0nO\xe2"
        b'\xd0\xc9\x02\x9e\xf5\xd5\xa5\x8a\x88\xda3\xfc\xd1\xa9\xd1\xa5by\xe0\xbdF]\xf9\xbc\xdb\x16\xbe\xddf)\xe6\xa3l\x89\xc0}\x91\xa8\x8c\xcb\x9b&n\xb5\xa2\xdf\xa6\x9e\x1dYF\x86"LC\xff\xa4\xd4\xbceC\xa3")'
        b"\xec\x0b\x1c\xc3JT\x98O\xe1\n\xc1\xbc\xfe\xbd\xfd`\x9c\xc95\x9fK\r\x8a\x81+^\xc8\n\x83\x8cO\xb8(\xe1Or+\xf4\xb5\x8d\xcb\xd9\x9eE\x1f\xe1\x93c=\x1b\xd1\xdeH\xc7\x07\x04\xfd\xaa\xa27\x82\x7f\xe7'"
        b'je:3\xe6\xed\x16\xdf \xe9\x8eQ\xc1\xf8\x00\xb7Kb\xa1R8k\xd6g\xcb\xf5\x85ewYK\xdcQg\x13\x1f\xe8,\xb1\xce\x05\xbe:\xdd\xdbQ\xfa\xe8\xe2\x86\xc6\xc5\x1c8\x80\rC\x85\x0f\xf0Z\x8a!\x8c'
        b'}\rn\xf5\x89\x17m\x1aokN/p\xdeM\xfd$\xd6.1\xb4e\xb8\r\xcc4\xa2\x0e\x98\xa6[F\xbd\xf6\x83\xca,\x0f\xa8>\xeb\xc8\x9c\x87q\xc3\xfc\x8e\x9di\xf6\xe8\xce\xd3\x1c\xbdW4\xde\xba\xad\\\x0b\x97'
        b'\xf2x\xda\xb2\x1dq5\xe7\xce\xc1R\xe7\xf7G\xe0\x84h0s\xeb\xd2%\xb1s\xe6^\xee`;\x94-q\xf5\xfd\xcf\xc6|\xa8\xde,\xea\xd8BF8\x80:j\x10\xc0\xd0\xd0\x94J\xa7\xad\x11\x0f\xffL\x9f\xce\xf3k'
        b'\xc0\x8b\x8f\xfbb\x18P\xad7@\xac\x1d\xf1\xdd\xd9\xb0<H\xcd\x97\xf6J0\x86\x16\x119\xc6\xf6\xb3\x1d*0\xe8ZO\xb05|\xea\xdcZO8>.\xb7\xc1\xf5LLN/\xc0\xef\x0e\xa1g\xa6\xcc\xdfw|\x1f'
        b'\x16\xdd\xce\xe9\xa8\x05\xa4\xedW~\x9b\xf8:l\xc2+\xdc\xc7\xbcR\x95Gt#?\xd9L\xd8%\xaf\x0fR\xb4z\xd8\xe5\xbf\xf6\x9ff\x1a\x84iS(\xbf\xa5\xb0\xd8\x9a\xff\xbb\xf05\xcf\xb7)\xcd \x0f\xef\xef\xd5`'
        b'\xc5\r$c\xc55\rk\xeb<\xac\xd5\x8c\xa0\xf9H\xd8\xd8.\xde\x10\xc4^\x04\x82\xec~\xe5\xe4.\xe5\xc0\xa4-I\xe1\xd8\\~\x8c:9\x9e^\xaf\xcfN\x85\xcf\x87\x86\xce\x08+x\xed@\x1f\xbb\xc8\x93\x82o\xc2'
        b'Q\x9d\x91\xf7"\x0e\xb1\xd5gB \x96\xa6\xd5KP\x86Zq\xe5\xfa\r\x8f\xdd\xef]\x8b\xa8\r\x19\xdfi\x08\x1c0\xe9\xa2lB\xe1uj\xe7\x03\xda\xc9\xd4M\xa8\'QW\x92\x88\xe3o\x12<\xa8z\xa9B\x9e\xc1'
        b'^);\x03`;\xf1\xcfa\xc5\xa2\x1a\xf0\x0b_+\x00\x84"\xfc\x12x\xdf\xd7\xc2B\xf1\xdc\x06\xbbD>\x07\x83\x16E\xf7~u$Y\xe5|\x8a\x19x\x8aJ\xde e%\x0eB;\xa3\xc3\rK\\=\xf8\x93\xe3'
        b'I\xf3)\xdc\xb8\xdf/fs\xd9\x9d\x88n\xbe\xa4\x15\xd3|$\xc2\x88b\xf5\xfb\xc1\x8d%\x82\xae\xd6\xb8\xf5J\x02\xd5\xf1j\xfa\xd9D\t,\xea\xf3dl\x1dn\xcc5\x03\x00d`4\x16^,,3\x0eX~\x04'
        b'\xaa\x9c\x92PB\xb9\x8b\x07$1\x0bG \x10\x84\x89qD\xd7_\xac\xd0\xf9\x9b\x12\xf6vG\xfag\xa7\x99\x85{\x1c\x7fbh\xdc\xc0^\x08\xe3\xe9\xdb1[\x94\xb28\xc7\xc2\nw\xcf\x99\x1bUz\xebM3\x12p'
        b'm\xdb\xc7\xc9\x0f\x1d\x1b\x0f\xfe\xffl\xf0\xb7\xd4\x1d\x16t$\xc8\x8cz\x1a\x94\x15\xfe\x12\xe8\xa1\xc4\x8d\r -\xc6\xc3O,\xb8\xef#\xd0g(M\xa2\xfe\xc8\x07gp\xb0p\xdd\x06\xf7\xc3\xd7b\xd8\xf1\x0cn\xbdn'
        b'\x8a\xdew\xe0\xdc\x0c\xe2\xd8\xfc\x8c\xcd,\x13u\xaa\x9c\xe3\x8c\x07>:o\xc8\xd8T\xc11{P\x12l\xd1Gz)\xa5\xdaE\x1d^o-\xa8\xc8\xe8\xaf\xad\t4\x9a\xf2fL)\xbf%O+\xa0\x05\r\x8fC\x16'
        b'u{\xf0g\xcc\xbf\x1e\x17\xcb[ \xea/\xee|\xaf\t*\xe4\xafuH\xd9T\xddl\xdcd\xc3\nSL\x95\x84wU\x99dU]\x9d\n\x0e\x94\x83\xab\xe3\xfc\x15\xae\xe1\x1cn\rwr\xe1\x0c\xda\xd8\x05\xe9\x14E'
        b'\x01k\xbc\x0e3\xea2\x8c[\xbay\xe5\x9a\x8e\xd9\xc33\xa3~\xdb\x1f\xe7\x8e\x9e\xf7E\x9f]*S\xd6\x88\xa0\x06\x11zLr(.n\xc0^\xb8^\x1bXm\x9eK\xe3\x15\x8bM\x96\xa1)8n7\xa1uh"'
        b'\x8f\x17\x87\x02<";N)\xec((v\x87\xe6\xff\xd9\xa52\n5\xbe\x1c\x9b\x02UK\xc0C\xe5k\x18\xcb\x8boF]\xb5ya\xb90j\xac\xcb\xca\n\xb8\xd8\xb4\xb6\xfb\x17\xa2\xd3T:\x08;&[\xc5|\x8a'
        b'\x1f\r?#\xb5J\xe3H\x10@A%\xf8O9\xea\x9a\x99\xa8\xdd\xbb\xb2\x87Adxii\xfd\xfd\x06\xb1~\xae\xb9\xf6cb\xfe\xd3\xae\x8d\x06\x0e\x9d\xa2\x85oVd\xd6S|j\xd8j~\x03\xc1\tJ\x94\xfa\xe7'
        b'\xa8\x8aZ\x95\xb6@blM2Y\xa0\xadX)\xe3BO\x0f\x82\x1e+\x0f\x15\xca\x89\x8b\x1a\xe7x\xeaWX\x08p_x\x1f\xba\xa9\xfa\xce\xee\x1d\x9f\xa8P\xb6ojq\xb3\xd0\x9b"\xe5h\x8b\x94\xc7\xc9\xfe\x83\xbe'
        b"%kW\xb30\xbc \x86\xae\xf8\xaa\xb8}\xe9\x97\x8e's\x19\x1eR\xc1\x9c\xdf\xeb\xea\x04\x01\xaf\xb9_\xf2\x15\xf4WM\xe1a\xa9\xa4q\xef1S\xa4L\xae\x11P|\xb6Q\xfe\x90Y\xdb\x8aC\xec\xf6\x0e))\xac"
        b'\xf8\xf3O.\xfe\xb8\x81\xd0\x95\xcf\xfc/\xa8f\x94\xb0W\x9d\x13\xa9\x952\x86lD\xa9\xbcxz\xff\xde\x10\xfc\x9c\xe2(3\xe5(\xe2I\xda/S\xd6>`z\xec}b\xacV\x0e`\x8a\xbe\xda\x16t\x85v\x06\xb5'
        b'\x8bNc\xde%\x08;eP\xdd3\x88\x867q\x16\x92Z\xea\x8c##\xe6E\xd5p\xebs8\xd4\xf2\xfa\xfd\xebODY\xb3\xd2\xaeI\xf0\xf9\xd2|6\xd9M\x9e(\x9bh\x80\x99\x9a\xe4g6\x18quH\xda\n'
        b'\xa6\xb6(\\y\xeb\x12\xd4\x8f\x15\x05e\xd4)C\t\xa2T\xda\x18\xd9\x18RT\xdd@i\xb3\xfecC\x9e\x08\xde\x15\xe9\x90\xfc\xd7Ba\x13\xbb\xa5;\x93\xd3\xf4\xfc\xe8Y\x98v\x02v\xbfT1n.,\xce\x06\xa4'
        b'[*h@\xfc#Gw\x16j\xee\x0f\x97W\xeaM\x8fd\xff\xa2:\x0fk6\xa1\xf7m\xf4XB\xfb\x02[\xd7\xd9J\xcd\x1f\xa4\x98\xbc\x93:U\xec\x89\xfd7\xd8\x81\x00\x08\xb3\xf6\x89\xec\xba\xc5\xc7Z@I,n'
        b'\x9a\xb6,\x0b\xd8bA\xd1\x0e\xfb\xec\x8f\xe4$\xb67\xaa\x96[1\xcf\x0e\x14\x11\xcf\x8f\xac\x11\xfb\xa9\x8dR\x89\t\xe2\xba\xee\xf1@\t@\xd2\xb0\x1b\xd3I\x0eC}\xe9\x92M\x96h\x97\x02\x82\xd3\x9c\x10\x12\x8d:c'
        b'\xb6\xe5Vt\xe7(`\x08\xee\xba\xf9hb\x07\xb5\xc7 f"|rA4Boo<\x1c\xef\xbd\x90D\x12\xbbI\x88\x00\x8bn\xe5\xf4\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0c'
        b'RuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.ib'
        b'an>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x03\x00\x08\x01\x03\x00\x11\x01'
    ))
