
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s6\x00\x00\x00y\x08\x00e\x00\x00\x01Wn\x14\x00\x01\x01\x01e\x01\x00d\x00\x00\x83\x01\x00\x82\x01\x00Yn\x01\x00Xe\x00\x00e\x02\x00e'
        b'\x03\x00d\x01\x00d\x02\x00\x83\x04\x00\x01d\x03\x00S)\x04z\x1afintech package not loadeds\xda2\x00\x00PYARMOR\x00\x00\x03\x05\x00\x17'
        b'\r\r\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x9a2\x00\x00\x00\x00\x00\x00\x1c\xfb\xab9\xb3\x9e\x03\x90\xc9#\xae\xeaPb\xba\xb0\x00\x00\x00\x00\x00\x00\x00\x00\xe5\xfc\xe5\xc6c\x91\x87O\x14LJ\xd7\xe9'
        b'\x1com\xecFN\x14\xd9"\x1b%vg\x83\x8c\x92\xd8\xc7\xfdF7\x02K&\x9a\x1e\x8e\x15\xd2\xbe\xf7\'JY\xba\n\xafo\xdb\x8d\xc53(\xd2W*Ayr\x90\'\'\x9d\xb25Q\x17S\x99,\x00z$&'
        b'\xb1\x83K\x9a\xd2\xffTX\xa0K\xe4j\xf9\xb0u\xb0\x9f\xd0\xf9\xc3IM\xa7a6\xffc\x91DV\xe6>t\x1b\xb5G\x1f2\xab\xf7\xddou\x19\xfafZ\x98R3\x87CT!\xe1\xc0\n\xa4\xc2\xee\xdb\xff\x98\xe0'
        b'=/\x0c\xb8y+\xe1\xa7ei\xb5\xd6\x84\xb7\x103E\x9b&\xc9\x16\x11\xbe\x03Z$\x02\x04\x0e[\xbdY\xe4W-\x1d\xdaJ\x83H\x19}rt\xb9\xdd\xaf\x8f\xc2\x01\xd5\xc3\xb9\x8ai*kz\x7fOv\x8bx\xb0'
        b'\x9d\xef\xb1\xd4*\xe5s{\x1eI\xb1k\x95\xaf\xb5\xb8X\xe1g\x06w\xe0\xb0\x97T\x01\xb3\xb1_\xf2\x9c\x97\x95\x9eB\x92\x93\x87\xd4u\x7f\x00"\x98\x8c\xb5\x93\x93\x15t\x19\xed\\i\xe8\\k=\x01\xbb\x08\xca\xe1a'
        b'\xb1\xf2!\x03\xd7"\xc6x\xa7\x92\x02\x12<\xc4b$i\xfb\xda\xde\xd5\xeb\xc7\xd3m\x84C\xb6\x93\xefh\x12\xba\x17\xf4\x8e\xae\xc0\x9doO\x18<\xf6\xb1\x82\xf0\x9cF0r\x95\xa7\xb82\x07Lf\xe1b1\xc0\n\xac'
        b'\x94\x92\x81\x95\\\xcb\xb1\x04\xf9\x81\xa1=\x04vqvy}\xc5D\xe50\xd2\xbd\xd0\xd3\x9c\x0eA\x01\xcd\x90\xba\xa9\x89\xc7\xa0!\xac\xc64\xa6\xaf\x1c\xc1]\x93\x86>@\r\xb2\x1d\xb2o\x06g\x81\xb7\xcfB6\x11d'
        b'\x13\x9a\x7f\xe3}kG\xed\xda\xd6\x93\x9f\x93KRa\xe8\xaeJ"{\xc7\xe1\xcfR\xf8\x9bu(\x94\x7f\xec,l\xc8\xf8%\xd7\x14\xb9:\xd3\xe1\x9a\xca\xf93Alo\x1b\x8b\xafr"\x9c\xe6N\xf0?\xd6\xd5)\r'
        b'\xeb\x16\xcf\xed\xfa9\xf8yf\xedZEr\xff[E\x84\x0e\xcb\xa2\xcak\xb5\x05&\xcfa\xec\x898\xa9\xa3\x91B\xa9\x82%)\x0f\x8b;u{\x92\x7f]\xa1\x11d\xfe`\xfb\x07v\x07\x0f\x7f\xbb\x99\xb5\xf3\xa1JM'
        b'\xb1=\xcfcc#\xa9B\x14\x9b\xa7\xf05\xb0\x99\x0e\xdaR\xea\xfcY\xa5\x1c\x10\x9e[\xd9\x0b\x8a\xc1\xed\xc8\x08\xf9\xe5\x96"i\x85h\xcc}\xb4\x1c\x0e\xb0FP\x06\xaeA\xb0\xd3\xbcg\xd8\x0c\xf9\xb3:\x10\x9e\xbf\xdf'
        b'\xe1\x14\xf8\x1a\xd1\xe2\x15/)\xae\xe4c\xc5\xd9|\x01\xa1\x0b:\xf8$\x97\x17\xed\xd0\x854\xaf\x1cm\xbaQ\x99T\x83vX\xcf\n\x1a5\x10T\xf5\xa3iRSN\x1e[\xedu\x8b\xfb&%\xa4ft\x87\x068\x85'
        b']\xd8\xd5X\x0eG\xea\x91\x13\x84\xe5\xefG\x87\xefN\xe5\xd4\xdd0O\xbf\xb3\xb6\xf6[\xe9u\xeed\x04H \xb0\xff\x04\x81\x85u\x91\x96\x0b\xb1\xb8k\x8e]o\xe5\t7\xf8J\x1f\xa42\xc2\x86[\xc0\xe1~"('
        b'l>\xc3\xa0\x9c2\xbfa\ni\xbf\x13\xbb=\x18\x1a\xfe\xaf\x92\x13\x07\t~}\xff2!A\xedm\xfd"X\xf1h\x8e\x9f\x1bj\x82\xe5"\x8d\xcd\xdd-\xd1e\x08a\xec\xd2\xbc\x16\x9e#\x8c\x91c\xca\xc9\xf8\x11k'
        b'\xac\x85$\xd1\x0e^"\xacf<u\xc4\xb0\x87\xcc\x99\x17\xd1[\xb3\xdeLq\x19\xa7\xe2\x1e;@\x9a\xd79\xdd\t\xff.\x97\xf7\x82q!t\x99\nX\xc2\xb6\xd5\x15[HbvA\xee\xb7\xc4p\xec\xe6X\xd5K\x19'
        b'\xc5%\x0e]C\x86\x93v\xf83>\xd1\x91 \'\x8eLG\\\xfaTE\xbb\xff\xd6\xaeNg(\xdb:"k\x1eS\xde\xbfJ\x8c\xd8\xcep\x13;\x87m\xac\x83]\x8d\xdb\x12\xb1\xd0\n\x18\x199\n\x01J\xa9\xa9\x7f'
        b"\xf4^\xde0\x99\x99,g\xb6\xe7\xaf\xdaQ\xb7y\xf0[\x883j\x1btVx\x8c&\xd6\xb0\xf7#IH\xc2>&t\xf5\x15\x91\x98\xbb|g?\x9c\xcd\x86\x1c'\xc0V\xd2B\xbd\xff\xb9\xb1\x1d\xdf\xe1\xcd\xd8\xde\x1b"
        b'\xeb\x07\xc8\xb3\xd9;\x8b\xad>\xb6\xfaQx\xd1\xd8\xfd\x83\x0b\x95#\x977\xe8\x89\\\x07\xa7\xe2\xeaz\x83\x05\x00r\xfaq\xc0\xdf\x9b\x07hm\x9d]\x12s\x1dI_4\xfb\xef\xde\xf5\xe5x9\xdf6Zk\x85\xc4A'
        b"\\v,!\xca\xf0$\x0273![\x8d\x82\x1c\xac\xd3#@\xb4\x9c\xd9\x9b\xc3\xf5\xca\x04\xa9\x0c\xd6\x11\xc4wC\x85\xb2KU\xff\xce\x9cf\xf9}\xae}\x04\x87e\x97'=\xa8\x95\xa4\xd8\xd8 n\xea\xe3\x0cfX"
        b'\xc1:\x8fe\x85Q\xd9w#\x08\x94\x80\xf9\xc0\x1c\xf5j\x95\x95\xd2a[\x02\xbca\x15\xfe\\\x9a\xdab\x81\x9e"\xef\x0b2\xcfaL\x87\x18\xf7\xfdW\x89\x96\xcf\x8a\x04\x80A\xde\n\x0b5\x81\x13S\xefq\x86\x06\x19'
        b'\x02\xac\xbf[\n\x88K\xd6MXS\xe0\xd1\xda\xf9\xfeK\xa5\xef\x80U,\xedI_\x02T\x14G\xbc\xad\xc0Z\x87%\x19s\x9b\xd6NX&{d\x89\xebBW\xfc\x1de\xf4j\x16pT\xcc\x0c\x99m\xb5\x90\ns'
        b'\x12\xac\xdd\x87{8-\x0e\xc9\x1bZ\nE\xb9\xe2\xcf\x89%\xff_\xba\xcd\x85\xa3l\xe2\x1dp\x0c\xf6d\x11\x03\xcf\xc8&\xef\x8f\x10\xc1\xf6`\xba\x9b\xd8!?\xc1m\x10\x1d\x18\xd9\xe8=\xf0\xa6$K%\xd03\x1dt'
        b'kC!\xf5!M\xff&d\x85O\x12qF\xd9\x06Q;\xfe\xc4\xebl\x00x\xc6\xb7NDr\x06\xd1\xb6\x9a\xc7\x03\xeb\t\xad\xb6\x946)l\xf0\x95\xec0\xd7\x9b\x9e%\xc03\xf7Z\xf0"\xb9C\xb1\x03\']\xf4'
        b'c!#K!\x81\xa3\n\xb4\xac\x99\xe6\xfe\xbe\x8a@:d\x1b\xc1\x9b\xbeZ\xdes\x9bk\x9a\xa1\x9b\xc7p`\x88\xda\xb6\xd8\xdc\xf9\x08\xd7A[\x87\x1cN\x9d\xe4=I\xda9\x92t\xce\xef\x14\xc9#\x98\x13\xd4z\xd4'
        b'\xbe# \xc0v\xee%d\x1a\xb3=\xb3\x1d\xab\x8d\'X\x87\x0e[\xf3V\xda\xdb\x12B\xc7\xdb\x07ZjRTq\xda\x06,g"\xd0\xdc\xbcrZ\x07\xf8\xd9\xedv~\x02\xf6\xbd\x89\x13]\xaa\xa2$Tu\x97CL'
        b'tfQ\xe8\xe2\xf1\x01O\x8fc\xb3\x0c(\xec\xe4\xe7\x84\xee\xbc\x03\x8c\xbew\xf6\xd8K_\xa6H\xc2u\xdfY\xcc5\xe9a\xc1\xaaZ%\xf5\x0f\x1co\xbb?\xa1\x9c\xb2\xd8\xa9\xfa\xf1?>NK\xc0r9\n&\xfb'
        b'g\x81\x00@\xdf\xcc\x85\x12O\xe1\xe2\x9a<?N\xc7G\xb8\x05S\xff\xde\xacP\xdd\xd6\x80Q\xa5\xd4\xaeb\xfc?}%r\xd3\xbdZ\x82\x03\xc1\xc1#/\xb7f\xd0H\x93T0\x8c\xa98\x9e2\x9eI\xf8\xb6\xf8>'
        b'\xfa\xf1\xcbb\xa4q\xc3\x98\xe2:@\x18\x81x\x0f\x7f\xb6u\x03}\x81\x8b\xdclaO\xc7W\x91\x1d\xca\xa4\xde\x1d/*H\x14/a\xc6J\x0e\x8e\xf8\x14\x9e~\xd9\x1f\x0b\x12\xfe-\x80\xe1!\xfc\xfe\xa0x\xffH2'
        b'\xa3\xfc\x99\xc0td\xcf\x9b_E\xf2\x10S\xe1\x06\x9bV\xda\xb5xm\xe5\xd0l\xcc%d\x16\xfb1GB\x9c\xec\xb3\x83h\xe22\xa9\x07;,\r\x0c\xd1\x19n\xba\xad\\\xc2ph\x10\xa3\x9a*\xdap\xc1\xa2\xd6\xb8'
        b'\xa3j\xe5\xa06\xe7n\xce\xab\xd7\xfay\xb0\xc2\xec\xa3z\x82\x7f\x84\x9f\x00~q\xf4W\xa2\x03\xfe\xfd\x1f\xfe\xdd\x8d\x97\xf3y\xa6\xe4\xee;\x9c$\x89E\x15\xbb\x17x\xeaHm\x88\xcd\x00\x8b\xb38G4\x8e\n\x0f\x08'
        b'\xa9\x9f\xdf\xf9\x1c\x14A\x9eKj\xe6v\xc5\xdd|(\x1e40H\xcb\x1aU|:;!\x13\x14s\r\rr\xea\xeals\x01eS\xb4\xd3\xed\xdf\xfd\xc9\xe08-&OH\x85\x82\x11Q\xd3\xceo@\xfe\x1d\xe0\x16'
        b'\xd9g\x1a\x07\xcd\x19\xd6\xd2\xf0\xf4\xf6\xda\xb8T\xc2\x87\xce\xe5\xf8\x87k\xb0J\x11\xce\x91$\x8c\x19\xdb\xbe{\xac\x8ac"\xad\xfb\x0e\x11RzR0Y\x86\xbe\xc8\xe1b\x8c7[\xc4\x89~\x00\x19\x13\xcb&\xb8\xe3\xb9'
        b'bj\xed\xc9\xf4\xeaK\xa1\xe9\xc3\x19\xbc_\x8e\xa4\xe0\xfch`\x8e\xad\xca\x89\x91\xc7\x17\xa3q\xc1U\x1e\xe4\xb7\xdb\xe8r\x04\xa5\xc5\x96\x8e\xbb^J\x1c*\x97\x050\x01J\xa1G\x02\n\xe5X\x87Q\xb6\\\xb2\x11\x13'
        b"\xf2\x0e\xb1\x84\x19\xda\x86\xbb\xa2\x97H\xee\x8f\xfa\x02\x94\x9a!\x98GW\x94\xdd.\xc2\xa6\x90\xf5#\x1f\xec\xbd\x8c\xa5\xcf\xb4\xe0\xe8nyz\x8c'4m?\x876\x04U\x9d\xe4\t9.\xba\x0c\xc5(\xad\xfc\xcd\xf43"
        b"\xa3\xc8\xcb\xea+\xe9\x03:\xaf\xd9 -*\x10$\x88\x00x\xde\x9e\xf8\rB\xa1C2\xfa\xaa\xac\xda\xd7\t\x8b\x80\xf0\xe3\x1d\x83Q!\xa7\x14\x84_\x17\x0f\xb0\x9a\xf5\x12\x18\xe6'\t\xfb\xecq\xcf\xefz\x87\xda\xfe\x9b"
        b'\xf4\x84\x84\xbb\xe0C.\x16\xe3\x1c\x08\r\x97\x93\xd6\x1dk\xf4\x18w\xe9\x96\xdeA2\x1a\xfb\xf2\xa8\xc1\x07\xe2\xff&X\x1a\x8c\xa1\x10\x11\xb9O\x14G\x01u\x816\xc0\xfe\xcdq1H\xfac\x95\xb7A\x86\x8aj\x8f\x11'
        b'\x92\xb6\xbf1L\x83Y;\x0c3b\xdaS\xf4O\x18@\x15)c\xe9\xf8\xd6GDL\x98\xac\xf0p\xe26d\x8e \x01\x04L\x91\x1e\xe05\xa3\xe3\xbaP-l\x07\xc4}\xe9\x92\x80\x0cP?\xd1\xeeP\xb9\xd7=q'
        b'@&A\x82\xd0\x1di\xa1\xb3\x12\x8c!\x1a\x1e=o\x96\xb6\x96\x9b\x04\xaa[\xd3O\x87\xe3\x9d\x87\x9f\xc4\xaeg3@I\x03!\xf0\xacrK\x19l\xcb\xbe\x03\x08\x94Y.a7*C\x86\xf3A\xf9=m\x0ePn'
        b'\x18F\x8f\xe0y e\xe1+xo\t\x06\xe0\x1e^\x99\xcf\xd7\x0bz$\xc4\t$\x08N\xe8\xc7\x12\x93\x07\xec\x0c\xfc\xe1\xef[\x84\x8f\xb9\xd4?\x92\xd8\xa16\xce\xf2\x1c\xca/\xf5\xe0\x8f#\\\xbcs\xb0\x85\x8d\x80\xb1'
        b'\x99C\xa7\x8c\x19\x95\xfc\xc8PW\x874\xae\xd9\x87"\xec\x99\xb4g\xc9\xbaW\xf5\xa4\xc4s\xb9\x98\x0f!F\x01\x87\tK\n\x89%7\xa8\x99CHV\xdb\t-$q\xe4\x90\xa9\x19x\x19g\xda\xc5YR\xb6p?'
        b'%\xe2\xd7\x8b\r\xfe-\x1e\xa0O\xc7,\xfa+\xbe\x95;\xf0@;\x8cKa\x01\xd6\xadETR\xeaA\x1a\xe0\xcb_\t:!J{-v\xd0\xf2\xed\x8cy\x86\n\xb9\xe5\xaf\x7f\xe6T\x164\xf9\xb0l\xdd\xaaM"'
        b'6\xac\xcf\xc9\x8b2\xb7\xaa\xec\x0fP.G\xf0"8K\xa105\x18\xb6z\x18\xc2\x99\xbf\xab6GnP\xc6eL\xf97\x8b\x0f{\xf2\xc9\xeb6^\xf54\xf7\xcd\'\x87k[\xdd3\x87\xa4!?%\x9e\xbfJ\xa9'
        b'CW\x81\xf3L\x08\xa2\xd5\xe3\x1d^\xba\xa9\xb8H\x9c\x06\xaf"\xbf\x1br\xed\x11w\x9a\xf5\xce\xc0\x01Ce\xb3\x04d\xd2\x00\xac<\xe1\x0e\xe4\xd3\x91[\xd4\xc9me\xc9\x1c\xe8^Tb\x7f\x8d\xe3\xc1\xea\xdd\xe7(t'
        b'\xd4hxC\xd3\x07\xe2\xc2\xf8\xc0\xc0l\xba\xcb\xd5C3xMwmdA\xa4\xbd\xa5I\xb4\xe7mrl\xb3F\xb4\x13\x80\n\x13_\x0b\x06O\x8f~\x04\x92\x98\xc4\x15\xa1\xccoj6hyE\xa8\xf75\x827['
        b"\\\xf2\x86\xbf\xef#\x84EX\xa5R\xb56\xd7\x80_\x0e\xdc\xc1\xda\x95\xc2z\x86B\xf3P\xd4\rpV\xba\xf6\xd8\xb2i\xbb\xd1\xe5p\xc3\xba\xdb1\xff\x80A\x02_\xfe\xf7F\xef\xd7\x1f\xae\xb0~';h\x16x3"
        b'\x0c`\x84\xe8\x81\xbdF\x8f\xf0\x9b\x11N_z\x91\x8ajc\xab\xe3$u\xfc\xb0\xd1G\xfc\xf1\x9d\xa5\xaf{U\xd1\xa2\x0fJM\xce\xf8\xf6\x9d\xf9{\xba\xc8\xabx\xde\xed \xdfE\xa8\xb9\xf9x\xb7\x88\xfeA\xbe\xb1\xb0'
        b'\x0e\xf6\xfb\xc6\xf8\x1bY->\\<"\xb3\xda7\x8a\x9eU\x84Y\xa6\x06\nskF\xa3\\]\xa9\xf9\xf3\xf1\x81#\x81\xe7\xcckZ\xd7\xa3)\x84\x89\xbfm\x98\xd3\xe7{\xd2v\x80\x0fs%\xad\xe2\xa8%4u9'
        b')\xf4\xc7\xe0v\xd3S\xfd3BWHzt3\x94Gud\x1d\xab\xe9\x8d\xc8%]\x00\x81\xbe\xcegd\x85\xddjL\x80\xbb\x89\x11\xfb\x12\xf9IS.E\xae\x892\x89\xffX(\xbeb\xb4\xec\x7f\x9d:\xb8\xf4W'
        b'\x02~\xb0~BC"\xd7C\xf5\xab\xb1\x00\x0e\xed\x97\xfd\xc1\xa0)M\x81\xea\x01z\r\x16\xaa\x10\x94.C-\x08\xc3\xb2\xa9\xf6[O\xbat\xaeD\xee\xfe\xfb[\xcb\xec\x92\xce2\xb3O0\xb2,D|\x1a?_\xe3'
        b'\xa1\xf6\x922\xf7\n\xcd\x16\x07\x88;\xa4\x02\x0f\xd1\xd4\x8b9]\x0c\x0bN\x91\x87\xa2*\x06\x90kL!J\x1dF\xf0\x11C\xa99\xd3{\x19\xd5\x01\x9c\xdd\x87\xc1T\xe0\xe5\xcb\xc84\xb2\xcaWQ2V,GQ+'
        b'\xcf\xa6Z\xf9\xc3>Mh\x910"\x93\xd9\xeb\xda\xd8n\x82\xcb\x8e\x9b\x0b\x80\x86\xf1\xa2m9\xbb\xf7\xffvw\xdf5z\x02\x1d\x98\xb1\xf9J\xf8\xa1C\t\x8f\xb5\xa7\x1d\x80\x80-Z\xa2\x1b\xaf.\x1ct1{-\x9e'
        b'\x00\x04\xf4\x04\x19\x86\x19\xf1\x84\x14\x9f\xb1)\xbd\x8d\x91\x9bz%\xc0\xd29\x03O\x9c\r\xd6+\x1a\x1b)?{?\xe8\x80\xb2\xa5\x92\xa3UC\x0e\xfd\x89\xc3\xc4\xd4iY\xe1R\xc6\xce(2\x1b\xc8xjg\xccN\x87'
        b'\xb1\x8dz6\xa5\xf8\x80\xc1\xbe\xb0\x19V\xe3\xcbC\xa2\x9cU\x85\xed\x06C\xeb~\xa6\xa2\x1a\xb4\xbb\xcd\xea\xe8\xdbY]\x0f\xc9J\xcc\xbe\x93\xdb9\x92-\x81\xe4\xa1Y\xdc\xf3\xdd\xba\xb7\xf3\xbb\xd5f\x14\xb5iB\x1e+'
        b'\xda\xa5*\x02\no\xc3\x97\xbdL1\xee\x9c\x93\x9f\x8a\n\x06\xdf\xbd?\xf8r\x83\x81\xb2\xe6k\x15/\x7fI\x99\xc6\xa1f\xcbg@\x96\xf0\xad\xd6Z\xffGD\xba\x03!\x99l\x05\x83L\xb9+\x89\x9b\xea\x96\xd30\xbb'
        b's+-\xeb\xc6\xe8\xeeY\xa6`n\xd9\xcbn\xb2\xaa\x9a?\xc3J\x0fv\x12\xc0\xe9\xca$\x05\x03\xf0\xa6\x05\xd7B\xf2\xb9\xc9\x83^\xc5\x1e7d\xd9.J\xd9\x93k\xf9\x96\x06\xed\xf4\xba\xcdx\xca\xc0\x07W\x01\xc6D'
        b'\xb2A8d\x92\xea\xc8\x85\x01\x80\xaeZ2\xf1&\x08\xfeG\x1f\xe9 _5\xe3\xaaj\xcc\x94\xef\xe6\xa7\xf3\xae\xd9\xba\x81\x9a\xc1\x81\x9eW\xba\x00U\xa7\x82\xdf\x1c\x07i"\xde\x97\x14\xbf\n\x06\x17\xbe\xab\xde\xbc\xbf\x9f'
        b'\x84\xa0\x97\xe1\x97\xbep\x02\x1f\xe5\xf2S2\xc4[\x1d\xe8a\x87\x01\x81^L\x17\x1cU\x07`\xea\x8a\xb0\xd2>Y\x17\xc3\xb0_\xaa\xed\xb6 b\x01\xe0\x17\x85\xa7\xaf\xdbnq\xeb\x10\xd1\xe8\x17\x1e\x14\xce\xb7\x97\xae|'
        b'\xe5N{a\xdbPA\x8a\xfd\xa4lR\xd5@\xae\x86\xe8\xd6\xd0\xbb\t*\x05\x153\x98\xd0p\x0f^k}\xeeXo\r\x81-\xf81\xe8\xce\x9a\x9a\xfd\x85\x12%\x92[^\xfc\xfc\xa7\xdb\x11_\x06cI:\x82\x83V'
        b'\xf6\xed\x00\xd2fl\x9d\x85\xdc\xeb\x7f\xd9\xcf\xc1#\xb0\x96w\x04\x980-\x9d\xef\x16\xfb\xe3\xbd\xdb\xbd\x99\xb4\x8f\xd1f\xceA\x98w\xcd\xb0\x08\x95`$\xb5\xa02\xce\xe1b\xf5\x18\x8a\xd4\xc2\x17t<A*\xe1\xce4'
        b",\xd5\xf4\xbe]F@L\xde\x91L\xc2\xa2RV\xde\xeb\xf8z\x8eG\x0f\x95\x9as\xb6\xc5X{1\xae\xdaE<[\x95\x16aY;kP\x16\x11\x93\xc8\n\xff\xd2X'!\xe1\xa5r\xc16\x97Oy\x9d\x0bI\xab"
        b'\x90+S\x80\xc6\x87\x08\xe0\xeaq\xe6W\x8b|n\xe5\x06\xb9\xb8\x92\xec\xb2\xb8\x1bA\xd2\xdd\xcd\xce\xc3\x0e\xf5o:\x02E\x9f\xd9Gw\x9b\x0f\xb9\x0e\xa2\xe74\x19Q\x7f\xf5\x9a\x05\xb7%\x98@ebVI\x18/M'
        b"\xec\x88\xd6\x13\xd7\x04'\x83\xe8\xff\xc6\xd02s.M\xebO\xd5\xb8\xd8\xb5PX\xe3\x80\x1aH\xe2\xaf\xa1\xc5\xcb*{\xb4V{\xa9\xcd\xd5<\xaa\xd4!b$\x8a\x04I\x84\x0f\xe1y\x87\xc8Fn\xb6\xf8\x07\xb7|\xbc"
        b"/-\x04\xdc\x10C\x1eZ,\xd4\x93\xc9\xa68'oU\x19O\x96\x07\xa5\xb4a\xe2\x05W\x0c\xe2\xecBe\x9d\x930\xf1\x1c\x9d\x8e\\\x95\xa1\x8em\x06\xf0V\xa3bG\x80\xd83\x00\x87Ql\xe4k`\x90D\x8a\xa5"
        b'\xff+\xd0\xc4f\x9c8e\x10\x9a\x18\xde{\x80\xbf=\xb6\xa7\x93\x1d\xf4\xbeB\xe0\xe1x\xf9\xbc\x1f\xc1\x19w\xb6\xe3:+\x8f\xa1Q\xc3\xa2\xf2\xf8\x9c&\x0f71\xec\xb6p\xf9\xb9z\xff\xa0\x9f\xea\xea\x90\xd2\xc6\xdc@'
        b'\xc9gG8\xd4\t\xb6gi\xb5D5\x06\x18H\x8d\xdf\x8b\x8a|#\xdcU)\xcb\xa2Y\x86\x99(\x14\x985\xd6\x18\x7f\xb9\xd2qc:\x18\x03\xd0\xa6\xbf5w\x94G\xbc\xcf\xb2\xc7\xad\x89S\xed\x9c\x80\xa5\x99\xd5\x19'
        b'\xb3yj\xb4\xfe\x0fY\xec\xe4\xf7\xc9\x91\xd8@\xaaC q\xd9:J\xea\x96\x16\x81\xa8J\xea\xa2z`g\xf4e\xb7\xd4/\xd3Du\xf0>\x11v\r\x84\x05 p;&$\xd8\xd0\xb6\x9c\xe0\x97^\xe9\x84\xbbz_'
        b'x\x10\xff\x99\xde\xca\xef\xd7\xb5f\xa2\xbe\xfb\xb2<z\x10>H\x03b_"\x99\xeb\x0e\xeaWk\x8f\x83:\x96\xd1\xc7\n\xc0\xb2\xfa^\x19\xa8vc\xd0\x11\xd3o\xcd\x85\x8b.\xe1E\xa2\ri\x06\xcftD+o\xea'
        b"\xbbl\xaa\xe9\xc4R\xb3%\xfb\xfc\x01\x7f\x1b\x9f\xca\xcb'\xbe}\xe1\x8f\xc0\xd2#N\xe5\x12\xaa\xb7y\xe2\xed\x06\xcb,\x9c\xad\xfb\xd6\xe0\xd4\xaftM\xb8\xaaK\x81\x07\x81\x955\x0f\xe1\xbdP\xd8j\xackR\x8d\x0e\x1a"
        b'\x13\xc0lA+)!\xaf\x9f\xaa7\x82\x93\x86\x96\x97\x8b\x16p\xd9J\xd21\xe9e\xab\xba\xa34\xa3\xcf\xf31\xabX\xb3\xbf7\xe9QE\xacq\x04\x88a\x180f\x1a\xd5\xed\x03\xa3\xab\x16\x93\x0e\x98{\xaf\xe1\x9c*'
        b'S\xd2\xda\xe1u\xdf\xf1\xee\xbe\xa9\xef\xce\xf6\xdb\x7f\x04\xda\xad\xac\x98\xb3\x06UH\xe9\x04\x96\xbb9\xc1\xd1h\x93Nt8\xb4\xabA\xb8\x89\xa7\xcbZ\xd1(=\xe9\x8e\xfd\xf8\xc4\x96\xce\x14\xe7\xa7n\xdf!\xad\x9d+T'
        b'*\xfd\xed\x94_Z\xd2\xcf\x11`\xef_/A\xaa\xa3\xac\xfd#?\x84Q\xa9(!H\xb3y\xbe2\xcc\xf5"\xbd\x84\xd3\x16\xf0\x99"\xbb\xc5P\x8dYg\xc7Y;\x05Pa\xc8\x12{Y\x94\xce\xc5\xc7\xd2J\x94\xca'
        b'P\xe3\x13\x9a\xb8M\x0e\xe4.k\xa9oF!~hJ\x03>Fp\xa0\xf0\xe2c\xf9(\xe2O}-s5\x9a6\x98\xa4\x8e\x11\xaa;j\x0f\xe8\x8e\x9f\xdcj\x8c;\xe3r7\xee<\xa0\xa3\x80e\xcf\xce\xad\x9eJ'
        b'cP\x89\xe7\xb2\x1c\xf8\xe7\xa6I\xb9C\x03\xc1x\xd6F\x81)E\xc8\xde\x12\x13J\xff-\xa7yq\xb6\x1a7\x1a,\x1e\xb2\xa6}\x13\xad!\x19\xdeBV\x80$\xfda\xe3\x07\x02\xf3\x02\xedY\xef6\xc8\x00\xff\xf5\x19'
        b'\xf3\xac\xee\x9b\xc8\x9f\xf0\xeb:\x0f?\x9e\x8c\xed\x11>\xa6\x14#\xc6\x0e\x95\x8d\xf8\x15^\xbc\xe3O\xe2\xc9\x16\xa4\xa2L\xb6\x8e/\x16\xae\xef\x15\xd5\xda@x`\xec\xe4 \x8bC\x81\xed\x9f\x8e\x8dH\xeb\xb4\xf2\xdc\x10\x81'
        b"\xeb\xdb<\xb2E[\xb8\xb5VV\x08Q\xbb\xc1=q\xcc\xb4Y%\x98\xcfJ\xb4\x8f\x8ai=\x92J\x13\xbe\x9b\x18\xfcN\xf4.(Y\xbc\x1d\x1fT2g\xc9Q\xb2f\xe7~9\xbd'\x97\xe7\xaaq\xb4\x1f\xa0V\\"
        b'\x10\xb3uD\xfb\xd9y\xdb\xd1\xa5\xf4\xc03S\x19l\x1e#\xd3\x94^i\xc0\x1a}.\xaap-\x80\x971\xd8e\x87\xa6\xd8ctC92\x9a\xd9\xf3\xfd\xfc\x89C\xed\x18gM\xc3%\xe8\xa8L\xeb+)E4='
        b"\x14\xc3\r\nF9\xc3\xfe.\xe9\x9b\xd1\xac\x1f\xc3!\xf2\x15\x8b\xda\xcf\x80\x92<\xcb\xcc\xff,\r\xaeo\xc5H\xf9'Ch\xd7^EO)\x99$\xa5M\xc42\r\x0b}\x1e\xd7\xe6\x90=\xbdI\xf7#\x16\x1c\xdb "
        b'\x1a\x89\xd0>4\x85P5\x0e\xfc\xb0\xf0!h\xfd@\x99-`.\x8e\x84\x85C\xac.\x8b\xcb\xbb\x9f\x01\xc7\xdd$k\xc7\x91o\xb9\xa6\x05\xd4\x83X\x12 \xae\xe6\xcf\xae\xc2Ay\xe9\xbe\xb7\xd7\xb0"\xb7e&Jd'
        b'\x9a\xe6\\J\x9dU\xbfr\x05bZ\x1f\xb2\xcf&\x1eF\xf3\xacDoM<>\xe5Gw\xc7\xba\xbf\x861\x93u\xa8\x11}w\xe4lx9d \xa8\x84\x9f\x1co\x8a\x1c\xcc[\xb5\xa9\xe4\xf7\xb7/\xb9\x8a\x1c\xf3\xd1'
        b'\xe0\xd4\x87pq\xdb8\x90\x061\xc2\xd8\xe6\x1b\xe8j\xfd\xf8\x80\xc6\xe3#24\x19\x98w/gL\xcdHu&~\xc2oz]5\x01\x83\x16S\x10XD9\x8d\xea\x89\xeb\xf7a*^\xe2- :\x7f\xafq\x80'
        b'G\xf4\x84\x03\xf7\xe3\x07\xa5\x0bw\x83#\xf4..\xd4\xb0\xe4Q" \xe5F\xa4\x1e\xc7\xee\xbe\xa0\xcew\xe6\xb5\xcf\x14-\x9a>\xe4\x85\x16\xd9)\x86t\x12\x80N\x19}\x06\xab\x17U\x1f_y\x0e}\x04\xa2Z!\xd3'
        b'\xc5\x9e$\x82\x97\x963\xea\xd3C\xb0Q~#\x7f\xd9/\x15\xbe%:\x11\xc3\xc1\xe1\x1fb\xd1&\xb3\xf7\xcfG\xb8\xf2-\xc3hf\xfb\x05\xb2\xa3\xfeh\n\x01\ntC9~\xec\xe4\xf44\xfb\x1d\x8bTq*P\x99'
        b'\xcd\xcc\x18\xb1\xc4\xd0\xc2un\x14\x8c\x89"\xa1\'\xf1\xee\xec\x0b\xd5\xe7\x08\xdb%W!\x0e\x9c2\x04\xcb\xf6V\x17\x8d\x10sXof\xdd\'\xbbg\x0f\xa5\xa5K\x98\xb4s\xf3Tn\xcc;xn5\xd0\xeb,\xf7\xfd'
        b'\xe0\x18\xe9^\x88\x134o\xb5\x0b\x942\x81u\x83H\xef\xcb\xb10,\xa7\x86\xbb\xcb\x81D)\xd0\x0c\x18\xd7\x06\xc4\xbb\xfa\x93\x89\xde,\x92~g-\x8b$N)\xae\x08\xb6\xfe\xe5\xefh\xba\xb9\x08?\x84\t\x8bm\x9c'
        b'\xce,0\x04\xcc\r\x90g\x04p\x9f\x08\xef\x0e\xa3\xd7+\xb3\x10\x12\xa3 \xb3\x80\x99\x8f\xa1\xf9\x8b\x86H\x94<NR\xfc\xc8\x8f\x16r\x95\xad\xfc\x9aA\xe0\x1b\x04\x9d\xa5,\x8a+\xdd\xb4P\xbe0>\xef)\xf76\x9d'
        b'Z\xbb\xc5Cu\x10\x87{\x9e>VH\x05\xc2\x184\xca\x88Cu@\xe9\xf3\xe4\x82\x0f\xfd\xf1\x06V\x83%\xfa\x0c$!5X\x0e\x18\x0c\xfft\xab\x86**\xe3\xf9v<\xce\xc3\xe8f\x1b\x1a\x8ct\xf2\xe0\xaa\x08\r'
        b'\xfbo\xfc\xac\xf1\xbbD,q\xf2e"\xfet\x051\x1dS\x06\xd7\xf8MGz\xfe\xd1\xfb\x80m\xbc\xe3\x89!\xd2\xf0\xb8\xdc\xfb\x15\x8c\xcf@\xd9\xec\xe4\x96\xcd\t\x83\x8co\x00\x993Y\xf86\x89\xc2Y\xd0\x11\xd9\x94'
        b"Q\x85\x80=M,1\xfe\x93\xf2\x96\xc9v\xf0[\xbcII0\xfbI(\xb3\x8a\x10\x90\x1b\x1b\xdf\xd4'\xa7\xcf\xeeS\xc19\xb3\x06\xc0\xb89\xc2o\xf3%\x98\x96\x17y\x85R\x05\xa5D=\x0e\x12@\xd5|,]Y"
        b'N\x80\x85\x1f\xc6Z@\xc9C\xb5#\n\xb0g\xfaCb"\t\xf0\xe5\xe1FZ\xb1]\xcc 1\x17\xff\x10\x11A*\x8f\x15q\xb8\xdd%.\x00\x93\x1a\x06\x94G\xcc\xdd\x05\x13\x08\x08\xd4\x91\xee\xe0f\x1fV:r\xa2'
        b'\xf2\x1faM_\xc8\x95\x9f\xb1y\xa5\x0eE%\xfc\xd4\x88\x12|G\xfc\x9e\xb8v\xd1\xd1\xe9c\xa1\x16\x04\x18h\xcb\xfc\x17\xe4\xb4\x81\x96\xb8d\xe3\xbdc\xa7\xa4\xc9\xc6$\x1a\xf4\xdcF5\xf6\xd4!\x86\xa8b\xf5Y\x7f'
        b'&\x82\x94\xd2\x16\xf3\xd0\xf0\x1d\x81^\x9c\x0b\xac\xa34\x10\xaf\xef\x16"\xb9\xaa\x10\x9ft\x89\x7fSD\x8d#\x14\x1bs[\xae\x01\xac\xe9\x98M\xb6\xde\xed\xe5@\xe8\x11\x83\xa4\x88\xc6`\xbf\x84\xbf\xe7V%\x0b\xc4|\xfa'
        b"\xcb\xdb'\xd2\xd02\x1a\x1a]@\x1d\x9f\xb5\x81\x0e\x92\x95S=\xc0_;'\x8c\x87M\xb3w\xf6\xe0~\x1e\xba\xc5\xef\xe7<\xee\x05^\xe1\x90\xc1\xcf\xc5\x1bb\x08\x1b\xbc\x1b\xfd\xa3\xfe\xa3\xacC\x0e\xe6$\xca\xf3\xad\xdf"
        b'\xdb\x19{2\xff\xd6\x9b\xb6\xc5V:\xc5\xd9x\xcd\xe5^0\x8eS\x8d\\\x15\xcd\xfbg\x96\xdc\xc8f\x8d\xe9\xc2\x03\xe1o\x18\xd6\x01\xdd\xf6\xca\xc3\x83*\x06mher\x12\x8c\xee\xef+\xcd\x04\x06~T\x02\x120h'
        b'q\x8d<\x94`8\xd2\xf5Q\xb7\x03\xd9\xc4\x00k4\xd7M)\xa0\xc5\x98+4\xf1\n\x85H\xbc\xc6#/\x07\xe4-\xa5\xed\xe5\x999\xcbt$\xc8\xc8\xafQvSD\xd5\xe9\x90\x1f\x94h\x0f\x95\xd3\xee\x88\x1c\xaeD'
        b"u\xff]\\J\xfaK\xd06`m\xde\xb2\x9d\xef\xadv\x92\xd8\x0b@\n\x0b|S?r4'\xa1jN7@a\xd8?\x98\xadA\x9aj`yj\xb1V\xb1\x0buL\xe8\xc5\x07\xee%\x10\x82F\xec\x8f.\xba\x9e"
        b'\xb5\x95\nJ%\x8b\x18\xd6\xad;W3E\xd4\xe8:\xea\x03D\xfc\x9f\xd0|\x9ab\xfc\x9f6|L\xd7Kn\xd8JW\x0f\xe8\x80\xa5 ;\xb4\xbc`_\x15\xf8S\xd3\xc5=\x00\xd9\xf6,+\xa7\x1c\xc8\xdeij\x83'
        b'\x04X\xc7KW5\x8e\xf1\xee\x86\xdf\xf0g{\\\xa458\xd3\xa9un\x04\xe5\x1aCm8%\xdf\x97\xea\xbe\xdcP\xc1(\xbe>\x84 6\xf1\x80pft\xcc\xcf\x06\xad\x7f\xc8\xbc?\x1c\x82\xca\xd0a\xffzCG'
        b'\xce\x93\xef\xf9{\xce\n\xc6\x93\xfep\x04g\x02\xf3I@R\xd6\xfb\x965\xe0\xa0sV\x1d\x04<\xc2\xa8\x97z \x01\x96\xb5\xda\xf0\xdc\xba\xc0\xff%\xffr\x95\xb0\xe1.\xe8\xe2?\xc0[\xccF\xfa\xa2\xa8\x9e\xb3I,'
        b'|\xc8\xca\xf5\xb3SF\xfd\x82\xd4\xbf\x1b\x83\xae\xab\xf5\xb74\xe6\xda\xa4/\x18\xac\x91\xd0\xcdL\xbb\xcd!\xd6\x98\xf67\xc3\x96\xd0\xc7S\xd4l\x81\xe6o\xcd\x8c\x1c\x92\xd5DVB;0\xe2>lz{I\xc9G>'
        b"F\xc5_A\xab\x1e\x88'\x83\xd2\xe8\xe4\xe17\xc0\x1c\xb1\xa4\xe4:\xcd\x83\x11p:9a\xe3\x04\xcb\x82r\x93\x88u\x7fC\xbcK]cb-\xfcg\x1cu\xea\x1e \xd4DU,\xbc\xf2XK\xafF\xf3\xfc\x9e\x18"
        b"h\xeb\xea\xb2\x08\xc4@\x0f\xf8\x84\x95\xb4\xecvMW\x10d-w\xa1\x89\xb9\xfbU5\x8b\xc3\xaa\x14\x1cJm\x96,\x83'Z\x87\xde\x1e\xc7\x8e\xce%,dD=\xec3k\xf3\x10h\x0cI\x85\xa0\xc8yA\xdc\xcc"
        b'\x98e\x90\xba\n\xee\xce\xb3\xf3i\xf3\xc0\xe7\x9f)$\xdaU[7$\xdbZ\xac\x15A2\xdbOTF\xd0\xf2\xc67\xc9J\x81\xcf\xe8\xc4\x04\xbf\x82\xa5o\xdb\xc1\xd9\xce\xb5\x837\r\xa6\xa1\xa0\x01)\x04^@\x7f\x9c'
        b'\xa2w`"\xc6\x0f_\x7f\x9a\xd0kg\xfd/\xb4B!\xa2@\x03\xf6\x1a\xd9W\x04wf\xf0Ux\xfc\x93\x072\x93\xe7z\xa8X\x01\xc6\x00\x9eK.V\xbcc$\xe8\xe0eb\xd6+@4\xe2\xcc\xf4,W\x04Y'
        b'G\xdcvV\xe2u\xf0\x08R1ci\xa6u\xce\xa1\xa8\xd9Q\x12\xc9T\xf1F2\xb7o!:\xcb=n\x8b\x0f\x8dc, \xcc\x1d\xdetu\xfe\x1cZn\x87\x12\xa1k"p\x02\xcf^C\x86h\x19\xe1\x7f\xa5\xea'
        b"\x14\xf4\xeb\xd5 \xa8=\xa3M\xa29\xa8\xb2t:\x87\xbf\x01\x90\x92\x9a-&\xafUA\x9aAD'\x011\xc6\xf8\xd4\xee\x04?\xfb\xa3q@\xed\xc9\xae\xd3\xa6u\xd9\xc6\x9a\xb4\xdd\x90\x92\xd3v$63\x16JU\x90"
        b"\x86\xd7\x04\xc3\xcd\x9d92\xb2h\x08\xc3F\xdd\xe9\xa7\tU#pZT\x8f\x92\xf4l\xecNe\xd9\xc9\xafU\xabI0\xc2]nM\x1dG\x88p$Y\x08\n\xad5\xd6(_\xb0\xfa\x9e\xa1\x0e\xfc\x13\xc1v-'"
        b'}\x17\x19H\xb4\xf9#Hw\xda\xd4\x88 m\x82\x05\xe9m\x81\xbc\x88Kx\xcb\t\xdd;\x87\x02%\xe3\xe6\x1d\xac\xc9\xfe\xef8\x8e\xd0\xe37\xcd8r\x8a\xdcrW\xaa\xa5J\xdc\xa1t\xa4\x9a]2\x95\x82\xb9ow'
        b'\xc5@\x96{a\xff5\xcfb2>t6\x99\xed\x8bT\x9eB\x18+\x83Nx\xe9Xt\xf9\xaa\x88\x83\xb9\xc7\xaf&5\x0b\xc2\xeb\xd1\xbe>iG\x03\xac\xe0\x07\t\xc0\xfd\xa3J\x9c\x15n\xea\xd6\xfbw\xd4\x12\x07\x8c'
        b'\x12\xb9F:hY\xaa=F\xcd\xd5\xe8f\x86\xdff\xf6\x98\x8b\xbc*>\xf6\x191M\x05\xd7C)\xdc\xdb\x1c!\xdf\xd3\x05"6C\r\x95\xac)\x1f3\x9f\xc9X\x07\xcdqa\xf9\x8b\xd2k\x17\xd0\xb9 6\x8d\x93'
        b'L\x9a$\xea\xb5CV\xa2i\x9c\xd6\x89\x1f\xef\xad\x85\nY\xa2\x06m\x9c\xf8\xb2\x9a\xbe\x9a\x0e\x86\x99\x04\x84\xe6\x11m\xdbwyw\x98\x93\x86\xe7{\xe1\x81\x9d\xa3\x02\xf1W/\x1b\x14\xf6kw\xd5h\x7f\xc8\\q\xd1'
        b'\xc6T\xd2\xdc\xf7g\xb6\x90`\xc3*\xc5\xd9\xf7$YSY;\x18\x86\x16E\xd6\xf9h\x18\x0c5X\xe7\x084P\x1d.\xbe\x05\x0b\xca\xc6\xdaX\xd2\xd8\xf4k\x94m\xf1\xd8\x04\xaf;\x06\x8a9*\x88\x81\xdf\x84\xf0\xd8'
        b'\xb5O\xf2\xf0B\xe6v\xe0\x1f@Q|\xde\xe0#\xb4\x7f\x91\xc8/\xf8l\xa2\xb44\xb2\xbd\xe8\xb27F\xde\xba\xdbl\xd3\x93\xc5\xa9\x8b\r\xae\x89\x97\x07\xf4Y\xab\xa8:\x8cmEu\xe6w@#\xf2\xd9H\x9a\xdd('
        b'6\x8c\xb6b\x0bo\x9f\xda\xb0\xd0\xd5\xd2\xd7b`x\x06\xa8z\x84\x800\x1a\xbd\xe8j[\x15G\xc9\xdf-zA\x7f(\x17\xa5Q\xbbO\x98\xad\xc1\xa9t\xa1PL\x1f\xda3\xfe\x85-#?.\xd0t\xbe\xd4PG'
        b'\xa3-\x9a\xf6\x17pb\xce\xc4\xa09\x9f\x0c\xd8\x15\xacN\x8a\x85\xf8\xcdW[\xe4\x7f\nK\xcb\x18x\x18\x7fl\xaeg\x98m>\xcf\x81\xf9\xb7kb\x92\xa3_\x91\x0cz\xd3\x05~\xd4\xa8S\x18v\xb8\x1b\x1a\xed\x1e\xc5'
        b'\x914\x03\xe2\x1f\xde/D\xd0\x81-\xf1\xb4}W\xb3\xf3\xfb\x9d\xecH\x0f\xf3\xack\x97\x18\xea\x01Q\xa1\xb4\x0c\xc4\xd2G\t\xe7\xfc\xb2\xd1\xe9\xcc\x85\x8e)\xf7\x97\x1c\xb9\xb2\xa3\xe9*\xaa\xed\x8f\xd4-{\xa6T\x06\x96'
        b"\xc8\xe7\xd7\xc2\xf6\xeb\xfcz\xac\xcd\xb2kh\xcfk\x1d\xf1\xfb\x1e\xcfA\xc7Z\xd5\x0e\x83\x93u\xe79\x89n\xa5x!m\x94\x95D\xc2\r\xfe\xaa)Q\xe4\x10'8\xb0!\xeb\x04@\x8c\x07\xdb4\x1fr=\x9e\xa5\xe3"
        b'\xec\xca814\xad\xe0\xbd\x1c\xd9zEI\xdf>\x94\xf4\x06\xe5\x9d,1\xd3]\xf8>\x8e\xadg>\xf6\xbfV\xb1L\xcd\x11\xcd\xd4\x19\xc8Q\xdd\xa6\xb3\xb1m(\x92\xfe\x93\xa4\xed1u\xb5\x9fA\xfb\xafr\xac\xa0\xe7'
        b'\x83\xf7\r\xdb\xda\xd4?\xbb\xa3\x19"\x1d\xc0J\x8f%\xe3h\x12\xc0\x8d\x853\xc0\x1b\x01\x12/\xac\x9c\x9c1\xc9\xf2\xd5\xc6\xefZ\xb25\x83-\xa4\xa9\xc8I\x8e\xfb\x08ao\xd0X\x91c\xebQF=\x07j1{\x1a'
        b'\xa2\xa8\xff\x84\xeb;B\xba\x8b[\xa1\x0f\x99\xc8\x93\x8e\xc0\x86\xac\x13\x9bh*\x98\x82\xa9\xf4\xb76\xea`\x81\xc6X\xa9\x19?\x04\xb6\x0cQ\t\xd0\x04\xc7]\x16\xc5\xff\xa0\x02b\xc6\xd1\x15\x97\xf1W\xb8\x1f\x8b5\xc11'
        b'j\xd4G}\x95;NdZ\xc9I\xc9,\x96\xfc\\\x9bW\xcf\xa0}\x89\xac\xd7\x80\xe2\x8d\x8d\xfa\xd6\xae;^\xc4nD\xea$V\n?\xe4jB\xdfS\xed\x97#\xea|!\xda\xc0T\x85\x9a~\x8a\xc4\x8a\xd7\x9b\xa9'
        b'\x9b\xbc(\xc8\xe8\x0c\x0e\xac~\xb6r\x15F*\x98#_\xaf\x98\xe8\x19\x06i\x82\xb1@\xf0\x1c\xec\xd8\xcc\xb6f\xd3\x1d\xc5\xeby\xf8U\x02,\x86A\xa2\x92\x8b\xd8\xf3\xc7\x14\xdc\x88t\xf4\x91}\xd91\xef\xaf Q\xba'
        b'\xbe\xfb\x8f\xd7\xc82~3J>W\xa6\x073[\xae\xd9a\x18\x06p\x9a\x0fC7*4\x98\xf1\x04\x97\xa7\x06\x1c^\xa0*a\xa8\xbd8\x19g4lg\xaf\xfa\x8b\xb9\x9en\xb6\xc8N_C\xfb\x18;\xfam\xfc\xd3'
        b'.\xcb"\xbe\x87M\xd2y%\x85\xcf\x15\xde^r\x0f\x06\x04\xcf\xdf{a-\xbel7S\x82\x97\xcf"\x01#\xf6L\xddb\xe2$?\xc2\xef\xac\x919\x17\x82K\xea`\xb3\x051HJ\xbe\x83\xdc$^3\xff+\xdb'
        b'U\xac=[\xd3XECm\xdf\x85\x01\x9b\r4\xc2p\xc6C\xf9\x83\xadb\xdfq\x18v7\xbf#/\xdb\xc2\xc7\xd9~\xf8N=C\x08\xe3\x86sG\xa1\x14\xdd\xb5+\x96h\xe1#\x06)\xf1\xfaam\xc7\x119\xfc'
        b"\xf2e\x01\xc7F\x12\xa7#\xe0\xdbEu+\xcaG\xae'+\xbd\xf6b\xf5\x19\x8b\x84,$\xb3Po\xc3\x98@GAV\x8b\x06\xd7<\x93\xb6\xe5\x19@\r\x83\xe4F\x17\xfa(k2m6\x90[\xd9\xf4]\x84\xa1H"
        b'\x8f \xccL1\xc6\xdf\xa4B\xb7=\xda\xb9\x95:\xe5\x8d\xf9J\x05\x1a>~\x89\xb7\x04Z\x84`\xcdws\xe5\t\x08\xab\x80:\xab\xbd\xea\x07\x95)\xfbkZ\x14b\xa5\x82\xc2\x8c\xe9\xfa?\x94\x84\xefTue\xe1>'
        b"\x06W\xf1\x02?-A\xc3\xf4\xdb\xd3BA\xcf\x9e\x1bn\xa3\x1e\x18\xdc=r#\xe8F\xbd\x92\x96\x1e\xc8\xc5\xaf\\].\xf2\x9c\xfa\xda\xac\xd3\xfd\xe6\xf0s}\x8f\xa4n\xad\x16rm\xb6\x89\xc6\x8e\xfe'\x80\x87\x1eZ"
        b'tg89_i\x04\x90{c\xd4HN\x10v\x06i\xaa\x81\x08:\x1d\xd1"\x03\xa68\xd8\xd8\xb8\xfdZ@\x0f\xc78\xf1\x14\xfb\n\x91\x7f\xf2\xf2g-%G\xc8\x1b\x8a\xff\xa5R&\x99\xe8\xd2\xa4)xgI\xea'
        b'X\xf0\x7fc\xb4\xdd\xaeY\xb4\x84\xa4\xdc\xeb\xe3/\x00\xc1\xb0UkX\xaa\xc1\xd2\x8c\x1e\xd5\xbd\xb3\\HB\x1cu\\\xa4\xcc\xcbR\x9ew \x92\xd8\xea\xb4G\xb5\x97\xb26\xfa>\xb0c\x86\x1c\xb4\xe6\x8f\x1bg\xe6K'
        b'\x91\xbd\xce\x9c-\xf4`\x14&,\xd3\xec\xbd#\xce\xcb\x93\xc5\xef_\x9d\x19\xcd\x1b\xbb\xf8\xcc\xe0\xa4P\xdb\xac\xc0X\xc1\xea\xe3E\xad\xb4\xb1\xe5\x9c\xd0J\x8c\xe0\xcb\x140\x90\xfd\x8ad\xd1\t\x08ed\x90s\xd7\x97\x88'
        b'\xe10\xf8\xc4\xbdj!\xc5_\x85\x92\xa8\x88T\\(?x#\xf9(\x8a\x90+\x80\x1c\x81\xa2\x9d\xf0\r\x91\xc4\xa9\x12\xf3\x06<\xdf\x1b\x18\x99\x87\\:\xde\xab[\xbc\xb2\x1f\x89\xd7c[\xd8.\xab\xfbsc\xdc/\x7f'
        b'\xcaa9\xd4\x13\xa1\xf9Y\xb4\x88\xf7\x85\xc2.\xa1\xcd?\t3\xed9\xb9\xaa\xcbr~\xbb, G\xc6\x05\x1buTh\xa3\xab\xb97;\x94i\x9a\xcd\xf3\x88R\xb4)\x1dxxt\xaa\xac\x99\n\xd9\xfe\x00}\xec\xf7'
        b'\xe5\xa3\x94l\xa7\xee\x15{Z$\xc0\xab\xf7%<\x16\xa7\x03$\xcd\xe98\x93\x9c9\x887\x84 \r\xca\x0e\xe4\xa2\x1an\x0b\xbf\x9d\x80j\xd6\x9d\x1e\xe6\xdew?\xb6\xff\t\xbe\x1d\xa0_\xd7\x06\x88f\xb8\x9f\x0fw;'
        b'y\xfe\xe4\xcf\x98V\xf1O\x14\xf0#\xb9\x8510#:\xaeK\x1d\xee\xa6\xb6@\x04\xc7?*\xa9\x1d\x0f&\x85\xa4T\xb3\x17\xee{\xff(3\x8e\x00\xe3\x16G\xd3\xc6%\xc9\x91\x06\x1e6\x03\xbb\x94d\xea\xe8\xe1#\xa1'
        b'Q\xbc\x85\xd5&\xf5\x19\xe8\x08:\x9e\x84\x1e\x05X\x19\xcf\xa0\xe6\x98L\xd2\x0f\xaf\xed{l"\xa3\x98\xcc\xe5\x02W\x94J\x80:\x051[\xc2\xe3\xbdu\xdelK?\x97\x8b\x96P\xb3\x8d.\xa9H\x82\xd7\xdcM1T'
        b'\xe8\x08@"\xf6Q\xf4\'\x15\xb4\xe9\xb4Y\x02\x0c8{\xd2~9\x10;\xfd`\xc5\xbb\xacj"$\xea\xc2HK\xc0\xf9\xc91\xd9\x08"m\xeaL\x7f\x807K\xe3\xfc8)\x17nktbw\x0c\xfc\x01\xa3\xd3\xea'
        b'\xa3f\\\x81G\t\x87\xbf\xd4\x07\x18\xdd=\x01N\x93\xd6S\xcfi\x93T\xd7Zn\x05\x0f\xbe\x15\xdf9\xe0U\xdb\xf6\xea;\xecJ\x1a6\xa8uP/L\x8b#\x12iVf\x0f\xeb\x95@a(\xd7\x02s\xa5b\xed'
        b'5 \xb3\xd6&\xcc\x16\xcb\x02\xc0\x08\xfc!\xef*D\x08\x8b\xe6\x9fk\xaa\xb1/SS\xc5gZ\x84d\x0f\x7f\x95\xee\xec\x93\x8b\xa2\xd4M\xe9B\x9eG\xbf\xdf\xe9\x8e\xf3\x19\xfd\x9c\xc9\x96\xb5\xaf\xd7z!-m\xd1\x96'
        b'\x16\x84\xc8\xce\x1e\x03B\xf0jK\xbb\x83\xc9\xe4M!\xa1\xd9W\xd6n\xc1\x93\xa0\x00\x9b\x90>"\xf2\x9a9n\xbb\xf1W0u\x05\xd4_\xf5\xc9\x10\xaa\xa3\x03\xc5\x9a:\x9c\xcdT=^s\xe9A\xd5%\x8e*\t='
        b'8T\xe2\x14\x18\x08kx/\xc5\xdf\xec\x96\xf4R\x9dDqO~\x951\x98 ^\x18\xeb\xbe\xf6\xe1\xb8a\xa2h\xba\xac\xa5YG\xcb\x10\x8cl\x84\x0c\xf4\x8e\xd0\x16\x88Csh\x8a\xf9;k{\x94\x1a8\xac\x95V'
        b'\xa1\xb8\xee\x94\xba\xf4\x05L\xde\x8a\x96\xc9\xab\xdf_2\xd5h\xdf\x84^~\x80\xf1`D\x06\x9e\xb7\x00\xbb*B\xda\x07Z\xc6\xab_\x010\x89wd\xd5\xc5\xc6\xce\xbb\x8d\xf9\x03\xc0\xd4f6\x1f\xf8K\x8f\x92\xc8C#'
        b"\xe8f\x0b\x05\x9d\x1a\xc4\xa1\xd1\xa3Y*E\xa8\xb3\xe4\x1c\xe2Gw\xd4G!\xf1'\xfe\xd30\xef\xd7\xdb\x13(\x99\xbc\xfa=)\x94\x91\xb4nZ\xb2\x99\xebUR\x04,nw\xbb\xd1$\xd82\xba\xc3\xc7\xd1\x1d\xd4\xec"
        b'\x0e\x8d\xe0\xe0\x96o\xdd\xb8\xdb\x8c\xdc+-\x9cz\x96\xd8\x1c4e0\x95H\\\xbe\xf6\xd6\r\xf8\x12\xa8(\xd3.\xd2\xf5\xdc\xcak\x98\xcaT\x16\xf5\xa0\x8d\xec?\xb0\x076\xe5\xf2g\x88\x1f\xcf\xa0t?\xd4+\xbb\xcf'
        b"\xc8\xa2s\xef\x1f'2U3W\xa8;\xee\xff\xb4\xb8\xe5\xa48X\n_\x95\xb2+:uq\xf0\xa5\x94\xb8\r]\xe2\xbf\xb6\xa37\xba\xf6S\xae\xb3\x8d\xe0\x8b\x02\xc9\xfb\xdd\xa5\xdb\x15\x8dT]\xadgB\x9bTU."
        b'\xfc\x90\xab\xf6_N\xe88\x17ixt\xd8\xd6\xfa\xbd\xf5\x1a\x05\xab\xbbo\xdc\xab~\x1e\xf1\x8f\xb6\xd6\xaeg\xb5G\xc5n\x1d\xd0\x96\x98\x08\x91I\xf7#\xd8\xd4\x8a\xdb?hh\xdfU\x90\xb4\x99ak\xe9\xae\xe7\xa8x'
        b'\xff\xfb\x7fw\x08K\xd9\xe4s\xee-\x04\xfcOD\xf07\xe0\x06\xb5\x98\xbaM\xf4\xb04*\r\x9b\xe9|\x81\x15\x00jO~\xa4\xc0\xbfoE\xe15\x1bc\x99\xfb\xce\x88/\x11\xca\xbd\x00\xad\xee\xac]69T\xf2\x13'
        b'\x99]\xad\xd1\x05\xbc\x90\xf0k\x9b\xfb\x07\xba\x05N H\xe18z\x98k\xfd\xfc\xe7\xff-\x11\xed\xc3\x17^\xa3\xecX<\x06\xce\xd0\xa9\xaa\xba&\xdb\xb9\xde q\xd9\xf8&j\xeb\x88\xd4\xdbH\xc1F\xcd\xf0[\x9bV'
        b'\xac\x01\xb1NQ\xa9\xa2\xea\x12\x90]\xfe6\x81\x0f\x90`[\x96_E\x92\x99\xca\xba6\xc9\x18\xc8\x18\xc4t;\x90\xa4\x03\xe6\xdc\xc2J\xea\x91\x92\xebF\xf5lF\x92\xcd\xea\xc4\xee\x95\x94\xb0[\xd1\xcb4\x14\xa8O\xee'
        b'\xce\x00-A\x8f\xf7]\xd9X\xd0t\xd8\x8a-\xb7\xb6\xcf\xde\x8ey9\x9f2\xd4\x95ZS\x82\x191\xddR\xba\x86\xee\x8c=\xe4\xfah9\x82\xa6\xbc\xbc\x8f;\xb7\x9c?\x07P\xac\x7f\xdf\x01UG%\xfc)\xe9\x07\x10'
        b'\xab\xfbc\xdb<\xbd\xd0\xf7\x04\x8e3\x87D\x94\xa0F\xad\x1b\x10\xc8\xbe\xf9y~h\x1f\xe0r\xc0\xa5\t\x8e\xd8\x08g\xf1\x01\nS8\xd8\xe7\x96\x01\xa9 u\xba\xe1A0\x9f\xa1\xb3\x1ad~\x95\xed)d_\xd3\xfa'
        b'1r\x90\xce\xe1\xed\xfa\x84\xb3\rF\xd7\x94\xcdh\x0f\xa3\xceiH\xc1w\xd4\x91*\xca\x16\x1c\x93?\xff"\x8c\xab\x86\x81r\x16\x0e@\xca\xd0\xa7\xc3xoG\x8a\xa7 \x9d\xfe`\xcc\xb5\x1c\xb4\x0b\x1en\xea\xe2\x824'
        b'\xb9\x94W\x16\x9e\x15\x95\xd2\xdf~;S\xb9\xd9\x81\xcaW\xe7\n\xaf$I\x10\xd7\xc13\xa4\x04\xf1\xfb\xe3\x1c]7L\x03\x8f\x15\x8b\x17\xdb\xbc\x88K\x82Ci\x19\x19dTOr\xfa\r~\xe6"\xcf\xda\xa5n\xc2\x8f'
        b'\xf7?\x83\x13\x08\r;\xf0\xc1\xc2\xeb\xbb\x1bh\xde\xa8\x88\xf5O\xb6\x9b\xbe\x12\x94\xc07:8\xfbLhM\x00\x19\x95\xcf\xd3\xde\x8f2\x07\xf0\x009F\\\xa2\x1b\x1b\xa0-\x7f\x19bh \x81\xb8\x89vwI\x13\x88'
        b"}`3}'\x16U\xb4\xdaP\x0c\x0f\x88\xac\x1byA\x90Q\xc3\x81\xaf\x88T\xb9\x80z\x88\xf4is\xdd\x93\xe0\x83\t\xa2\xf0\xc4\x03\xda\x9dD.\r\x9d\x9dKX\x8d.\xdf\x0e;\xd2YvMv\xd7zF\xff\x84"
        b'\xa0\x03\x12\xcdH+f\xe8\xe0\xa1\xbb\xb6\x16\x89\xbcG#\x11\xa7zyS\x89\x8c\xb2\xcfX\xf1\x9cW\\\x079?#\xa1\x9a\xbf\xf0\xfc\xde*\xf8\xd2\x16\x8f\xf8\xaa\xc3dC\xe6\x92\x99\xb2\x1b\xd5\xed\xe7\x9a\xec\xbb\x97\xed'
        b"]\x19\x88\xfc\xd2\xa3^b14\x15\xf4`7-z\xd85\xa6\xd6\xe3\x8f+\xc2\x88QN\xe0\xaf\xb5\xad\x8a\x16Y_u}\xee\xc5>\x95,\xe6\xf3\xd5\xaa0\x00\xfe\xae\xcc\x83\xd9\xd1\xf2X'U0d\x15Ex\xfc"
        b'\xa1\n\xfaJ\xb8=L$\x02\x8a]o\xba\xde\xfe\xe3X\x05\xccj\xff+\xd5\x9b4A\xd7\xc6\xcbX\xb3\xc5\xb5\xb9\xb6\x8dN-P\xccT\xd1\x88\xb9\x83F31jbhU\xc6&\x05\xe6\x88\xc5\xfbB\xf8\xd3\x04\xe9'
        b'\x0c\xa3\xef\xed/\xaf\xdd\xca\xbc\xe91\x04\xd6S\xb2g\x87T\xb2\xb6\xf4\x97!V\x97\x14=wf\rt`\xfc\xcdIS\xf5\x11\xca\n\xa8\x0b\x7f\x9f\xa0O\xbc\xe7p.v\x92\xcd-\xd7\xf6\xb8R\xa9PK\xb0\xb3k'
        b"l\xd9\xa1>\xc1\xf0N\xa6\x9b\xdd\x93o\x1b $w(2R\xd5\x94\xbcz\xf0X\xfdQ\x8c\x0f\xad@Vb'r\x81\xa8\x1eG-\xd5\xf4\xc9\xb3\x8co\xca\x15%\x7f\xbe\xa7\xef\xd01n1zI#s\xf8\x91-"
        b'\t;\x87W\xe5\xfe\x06\x0e\xa5H\x97Q\xc9\xf2\x8e%\x17u\xec\xd2~\xd8f\xf6(_3\x8fR\x98\xa6I>\x0f\x1e{\xac{|,\x1f\xd1-r\xc0\xc10\x8ccN\n \xf58\xd5\xb2\xf2w\xcf\xc3\x9a\xfc\xab\x05'
        b'\x94K+\xb0\xe6s\xceR\x0c\xe4F\xf2Z\x82e\xefy\x8b\x98\xbdQ\xdd\x12p\xef\xec\xb1\xdc\x0e:/k\x99\x18\xf3\x0e\xf5\x10\xe7\xf0\xbd-m\xd4\xe1\x9b\x10\x08\r\x97\x89nX\xb9\xfb^-\x1f\xaaK7\x84\x1fg'
        b'\xa8ljR\x03\xf1\xfdT\x8c/\xab\x04.\xcb\x08\xbf\xfa8\x00q9\xebf\xbcxV\n\x8f\xb6\xa2\xdf\xc0/s(V\xf2\x11\xfb\xd7j\x7f\xb8\x85S\x81\xde\x084\xb8H\x81z\x84\x97\xfb\x85\xa0\\\x89\x89K\xff\x8c'
        b' \x83\x00!\xef\xdf+C(\xc6\xd0\xcc\xealJ7\x7f\xe2Y\x92i\xa7@U\xf1\xda\x85\xaaI\xa3~\x9e\xc1\x91=v\xe3\x96\xc0\xdf&J\xb4i.^y(\x0b\xfdV\xa8\x07\x92\xe7\xdb\xb0J3}\x9e\x90\x11\xb4'
        b'\xe3i\xd7\xd1>M }\xd5q\xe1\xab\xd7Y\xcf\x92_\xb3\xd8j\x05D\xea\xa3\xf2\xd6\xcc\xd7Xg\x886\x10\x91\xd7\xf8\xd2\xb5w$\xdc\xd0"9\x1c0\xe74\xb62=\x8b`\xfc\x04\xafaT2j\x06o\xd3\xce'
        b'\x9c\x82Vl\xb2\xa3\x85D\xed\x16\xa8\x06\x93L\x03\x98\xee\x04\xe6c\xef\xf4\xbf\xb0\xac\'\xf1YY0{\x99\xad\x04u\xf5\x98\x1d\xf5\xb2.dL\x028\xff\x8e"t\x00\xe7\xb2z\x1e8\xba%O\xdf\xb0\x88\xdd\xb47'
        b'~Uir\x815\xd2\xf5p\xdf(\x15#\tM\x81\xd1\xc4\xcb\xda\xe7\xce\xd0\xb4Y5d\xcc\xd3,\x8e\x11\x84\x02\xb9z\xb7y}\xa4/;\xb1L@\x9f\xe5\xd0\xcc\xf60\x1a\xe2?\xd3*H\xa7\x18\xc4\xaa0n\x9f'
        b'\xc6\x9e\x80\xa7\x97?O2\xde\xdb \xcfc\x03G\xbd\\\xbb\xf7\xfb\x1c\x12\xe8\xe6l\xe3d\x99\x97\x97\xd3]m\xd2\xd1Hx\xaa\xa4\xea\xd5\xcc{$\x90\xa9\xb2\xcb\x98m\r\x1e/\xe3\x05n\x05\xf4\xc0\x94c\xfe}\xd6'
        b'\x86o\xab\x9f\xc9\x17\x80\xd4\xddl\x043\xb1\xa1f\x8c\x89|^\x88*l[\x95\x91\x99\xd3\x08\xfcC\xd7\x00\xc1w+#Zmy\xd2\xfc\xce=\xcd\xf4\xc09\x08\xebjX\x81V\xd4e\xcft\x1bP\x91\xf3$\x8a\xdc'
        b"\xf7v\xd6\xb7\xc2\xe8\xa3#Y\x13W`\xb7d\xd8(\x0c%Y\xcf}g\xec\xe1\xdd\xf2\xb3Y\x17?98\x83\xc1'\xecO\xc3`aC\xa5\x83\x13\x0c\tI\xf0W\xfc\xc71$\xa4\r\x07\x0e\xc9j\xc2\x10\x9f\xf7\xd1"
        b'\xcd;\x05s*B\xc6\xa9\x19}\xcd?\xcc\x04\x8d\xb7\xfbkj7_7\xfem3\x95\xef|\xf3\xf2\ri{\xce5\xe7\xb5\xfd\xdc((\xec\xb6\xfd\x8c\xef\xc9\x91G\x9fu\x00\x9bE2L\xd7\x92\xed\xef\xdc\xa9\xd09'
        b"t\xcaC\x1d\xc9\x87\xce\xc2u\x0eS)\x00\x8d\xc3\x13k\x8f\x93\x02\x01\xcbNb4\xa0 \xe2*\xde\xa1P\x93\xaa\xac\x96 s\xec\xc0\xd2\r3\x1c\xaah\x1e\xa7\x83\xeb\xb5\x06\xe3Ua\xdbY\x0c\x96\x160\x8c\x85'"
        b'\xafn\x93\x00\x8c\x18\x9f\x04\xd8z)\xb8\xaf.\xbd\x9b\n|8\x17\xc5o\xb1[\xb9\x86\xdf\xc1\xbf\xf7p\xa1\xb5\xfe\x11x\xce\xffI\xf2\x90ar\xd2\x1b\x9f\xff\xa9\x8b\x85\xd2\xce\xc38O\x8d\xe3\xf7\xe1\xe5\x81\xdd\x08$'
        b'\xa8\x1a$\x87\xc9z\xd4\\\xc7gcuR\x00\x8e\xba\xc01\xfc[\x92*\xe82x\xa6\xc5\xa7\xe6\xb8N\x84k<dE6d\xb9E\x8a\xe2\x8b\x05\xca\xaa\xbd\'@\x02~\\\r\x8e\xc6\x1a\xfd\xdf\xb7B6\xbb";'
        b"\xa6\x9f\xb4\x03;\xb8Iu\xd3\xac&\x828{\x8a\xf1Ka\xadCn\x11\x8co.\x8f\xe1\xc9*\x97\x82 \x95Q\xc2\x17#\xbb\x82\xad\xab\xd0b\xe0n\xab\xed[\n\xfc\x99\xf6\t'\xddaZ\x16\xc3\xb8\x9a\xe3\x9c\t"
        b'\xd9\xc6\x17\xb04\xb1\x15\xcaf\xab\x7f\x9c\xdbg\xb2\xff0\xe4l\x02\xd3\xfc\xabO\x8a \xcb\xa4\xc8S\xd3\x18\xdd(\xba\x9a&6\tZ8\xa9\xdd\x88v\x8d"1@Cf;\x11\xb7\x90>}><w\xb0\xe2\xd1`'
        b'\xa2\x82E\xafE\xb2\x98\x0f\x96\xa3\x06\xbc\xf6\x0c\xb3\xd7c2\x00\xa0\x0c\x8a\xca\x19\xd5\x86\x90\x17YB\xe4"\xbd\n\xfbB\x0f\x16\xa2\xfe\x15\x00\x80\x0f\x9c\xd5{\xd6h\xd2\xc3\xebup/\x18X\xa0\x8f\xdd~.K\xc1'
        b'\x90w<l\x9e\x8c\xb8C\x0bq\x0c\xfc\xce\xc6\xbeL=\xc0fs\x90\xaeu\xf1$4\x95\x80\xaa\x9c\xed\x10\x7f\xaf1\xb5\x92.6\xd0\x9b\x8f@\xb7ZrMq&\xb9\xdbd\x8eO\xa0\xa9\xa0\xe9\xd8\xd7\xd39\xa8\x9d'
        b'\xca\x18\x0b\xe0\x06v\xbb\xbd>?1\x0c\xb4[5\xf6G\x92\xce\x96\xc6nY\xc5\xb1s;\x14\x93\x9bC\xf0\xe3\x02$\xcc\x94\x07\x8f\xdb\x01\x80m\xf3\xb5\x83A\x10\x08_\xeb7t\x87\xb5\xd75\x0c\x8b\xc6\xe6\xf8\x18\xb7'
        b'\x99\x0e\x91\xf9*2X\xe0\x9e,3\xeb\xb0\xd9x\x83\xa3\xb7F;Ed"[\xd6\xa854\xe1="\xfc\x87\xa2\xb7\xda\x9d\xee\xfa52\x17\x8a\x91N\x07W\xb6\xfaA\xc0\x9c\x10\xf9\xf6R\xc2\x1a\x7f\x90\xa4g}-'
        b')n\xeb\xd1\xfcv\xed5\xe1\xbed\xd6\xc5\x87+\xc2\x94R!\xb8\xab/\xa9)"(\xc6\xf4\xf7\xd0\xdb\x8e\xa7\xa0\xbb\x9a\xb2$\'r\xb2\r\xe3\xd2T_$\xbd\x94/\xb3\xccb8\xb6\xa4\x85H\xef$1C\xe2\x16'
        b'\x07\xc8\x1fo\xad\xba:j\xc8\x88\xf9\xeb\xa1\xb9\xfe/zBk\xba?\xaa`\xb4g\xa4\xe8\x81.LF\xa3\x81\xea\x1e<\x1at>}\x04\xda\x01\xf5;|\x81=\xe1\x17\x03\x86f\xa4\x90\xf1\x9a\xab\x84\xcf:\xcc\xb5\x7f'
        b'9\r\xaaU\xa9K\x1cGX\xaf\xe1\xe5#\xed\x93\xcc\x0b\xa1\xc4\xf1\xd6\xf4\xd5\x9bp\xd8p\xd4\xae\xe6\x86\xf3\xd1\xfa\xf6\x91?\x18\xe6s\xa2!\xbe\xf1\xb5\xd1&\t\x12\x01\x90\xde`\xf9J\x91\x83\xc1\xb8[>@2\xe0'
        b'\x0e\x17\x0b\xb2*\x7f\x9c\xf6a\xd8\x08K[\x80\x894\x9a\xdd;{m\x15\xd0a\x8eTP\x17T\x9ae\x87\xc2bUc\'\xb2D|"?\x1a4\xcfYD\xf3\xd6!\xceq\xa7\x7f\xad\x1d\x08\xc5\x03\xc3*]*x'
        b'\xea\xbe\x0f\xd6,\x8dZ\xc5\x04\xefx\xac\x01\xaa1\xc7\xfe\n\xb2\xf1S\xd2~G:zA\xc5+\x03w\x13\xa1g\xf3\x10\xfc\xc0\xf5\x87\xef\xd2\xa4bX\x8123T\xd2y"\\`GbX\xd5\xc2\xa33Wi\xc6'
        b"\x8e\xb4\xa0\x99\xa5i\x04\xb8\xbe_mmg\x1d\x9f\xc1\x84k\xe3?\xb6\x9fz^Xy\x95K;$r[\xe7J~\x81\x8fB\xcc\xf2\x11H\xd3|l\xc0\xb3\x11(3\x85\xea<g\x0f'A&\xd25\x8fA\tL"
        b'H\x19\xab\xc8Q\xa9\xd2\xc2\xdc\xf7\xa7a\xaeI\\\x0b%N\x88\xcc\xa9\x10\xd1\xa5\xcb{\x13|\xfc\x05\xd9\x07c\x91\xe1Oq\xdcb\x9a\xb4\xaef\xb9\x18\xf5\xf4\xacX\x10\x8e\xf8\x0f\x95\x05\xca\xae\xee\xbbt\x9d\xc7\x9f\x02'
        b"\xa2\xa1\xadq\x02\x03\x8b\xe6\xfb[!%EU\x0bv\x8a\xd5`\xa1\x90\xb3\xaau\xff\xae\x05\xe2\xbf{'\xd0\xafv\x08:M\xd4`\xea\x8fe\xf8D\xf5\n8\x98\xbfE)Rm0\xef\x9e\xe3/\x9a\x1d{$\x85\xb7"
        b'\xb3\x00\xe9F\x97\xf5\xc2/\xccKd\xf8:\xdf\xe1\xc2\xbe48\xfc\x07\xc4Qr\xbf\xdd~w#\xde\xeb,T\x9f.\x9f\x98\x883\xa3T\xe6\x9f\xd3\xbf\xb3\xf2/.\x13\x9a\xa5|C\x03s\xef\xcf\xb3s\xf8\x1f\x19\x93'
        b'\xb0FI]!e\xdc\xa8?\x9e\x83MhB\xf5\x1ae$\x90c\x1cW\x89\xcd\xe9\x8a\x93m\xd62\xed\xee\x0b\x9bA\xe8\x13n\xf1\xc4<K\xf1\xe7o\xdd\x87\x15\x11\x91]\xbc%ch\t\xf2r-\xa9\xd1O\xa0\xff'
        b'\xdaw\x9d?\x85\x89\xe3"\xdd\x8c\'_\xbbS\xd7N\x0e\xc7\xc3\xa5\x15\xb0\xa3eD\xdc6\x02P[+iox\x16\xf2Jdw\x08\x1e|\x9f0\xe0\x86W>\xe2m\x8d\xee\x1a\x12\x8c\x13\x9d\x17\xe0\x05<\xf1\xa8\xd7'
        b'p\xd0\xc9\xc9o\xef\xf3\x8f\xa2\x9c8`|4\xea{R\xc4\x96\xad<9\xe0R\xc5\xf6c\xdf\xde\x90`|Q\x9b\x8d\xd9\xa9\xd5\x84\x18\x13\x8d\x06\xec\x18\x8c<\x01\xacY\xf5\x80\xdcq\x1e\xdf\xd9\xeb:\x08i\xeb\xad\xdc'
        b'\x86!_\xf64\x1f\x96\xe3\xcb\x13U\x83\x8e\xf4\n\xdbB0Gq\xb9\x90\x8c\xa3D\xb8e\xc9d\xcekm\x06w =\xf8l<\x1e\xfb}3\x9d3\x832\x1d\x89X\x961\x19\x85\x82\xbc\x00\xa2\xe7+\xf5o\x12\xe1'
        b'\x7f\x81\xa9\xee\x0f\xcbp\x9e9\xae@\x1c\xaeL\x1c\xd4\xf9(\x16\xe95$\xaa\xed\x0b\xa0\x93\xf5\x0b\x00\x92|\xdb\x99j\xf2\x03\x9cq\xea\x86\xd9\xab\xe0\x14\x9b\xf2\x9a\xda|\x94\x18\x87\x16V\xc25\xca\xd9\xd2@B\xd1='
        b'$\xa2\xd4\xc9\xd93g\xda\x0f\x17sO8\x1d\xcc\xb6\xf8\xb3LDd\x95\xfd\xca\xfb\xfcde\x1e\xfc\x11\xe2\x1c\x9b\x0e\xc5\xee(4\x9b\xd7")\xf4\x85\x1d\x0cB\xd7\x1e0\x12`\xa9\x0b\x05\x05\xaa*]\xcf#\xde\xec'
        b'~\x02\x15\x10\x88\x9c\xddC\xf4dq\xb8s\x85^a\x13\xa1AD\xff\x9d\xdc\x8bZ\x0e\x80\x0c`|%\xefOf\xa5\xc2\x82$E7\xd3\x9dW\xe8\x1f\xe1+\xa4\xae\xf5^\x80h\xab\xb46\x10\xd6\xf9\x19\xf6\n\x92e'
        b'N\xbfr\xec\x97\xf8cZ\x8ck\x03U\x83\xa4\xdd\xe6y!\n\xdba;\x1dj\xa2\xd1\xd7\x16N1j\x16|\x8d\xc3&I\xbcc\xb1\xb8\xab\x9e\xfb\x9e\x8b\xa2?~\x0c\xdcJ\xb9\x843\x99\xd4T\xb34ru\x89p'
        b'\xc3`\xb9\xc1F\x0c\xab\xc1+\x17\xf7vh+E\xbc\x87\xb7\xe7\x1aoPs\xb2\x1d|a\xf1\xf4\r\x05\xf9\x14ko\x0ecz\xcf\x16\xb6\xe7W\xf7\xe3\x00\xfa\x9a\xcd\xa7.\xa1uB\x84\xe2\xd90O\xab\xeb\xdb\x0e\x8e'
        b'}I\xbd/84\xfc\x9c\x07K\x17\x9c\xd4a\xfa\xb3\x1a\xfc\xf5\xd1\x1a\xf3\x1e||\x10\xe1\xd3g\xdd}8\x1fi\x8c\x95\xd5E\n\xb3)N~\xc6\xe9\x01\xd3{\x8d\xf6St/\x97w(\xb0e\xaa\x05\xc0\xc4\x97_'
        b'u7\xc2@\x84\x05\xa3\x00\x85\xfa\xbey\xe0)\x9b}\x19\xd4\x01@\x8e\xa3\x17Z\xf1\x7fCv\xe6\xcf9\xad\x1d\xbe\xdd\x10[\xa4\x94o\xf9\xb8l\x982\xddw*T\xd3\xe3nl\xfd\r!\xee\xa1\xbaT\xe1\xd2ZP'
        b';\x92\xf0\xe48\x97Z\x03Z\x8c\x84\xc55^\x8b\xc9PE\xc0\xb0\x94\xc0\xa4deZ\xf0\x8b5h\x7fk}O@D\xc6G\x97\xab\x87tv\n\xf0;\xa5O\xb0)\xc6`P\x83\x83X\xda\xb2\xe9\x0f\x1ep\xcb\x16'
        b'.\xf9\xe40O\x00e\xb4O$\x84\xa3l\r_\x9d\xd3\xec\x0e\xbe1\x12\xdah+\x03\x91\xb6\x86\x1c\xd4\x90>\xf7!H!\x7f\xa8w8s\xa0\xee\x9c\x91G\x8dbq\x0b#\xaa\xcaf^\xbe-\xd7G\xfd\x19L\x04'
        b'K\x84\x91&\x93Iml\x17\xc2\xb1\x15\x91\\\x82\xfe\xcb\xba\x18\xa0\xaa\x7f\x10brA\xaf>(\xe9Yv\xef\x04\xd9\x8f^\xafo\xa6t\xdeA:\xf0\xf1\xd0\x8e\xf4O\x16\x14\xe4\x8e\xb5\xde\xaazB\r\xfe\xd5\x1c\xaf'
        b'\x9a\x93\t\xaa\xf6pI\x80\xe3=\xb8\xbb0"%\xfcD\nT\xbdC-\xccMB\xb8i\xc4\xda\xba\x92u\\%\xb1\x83\x08\xc3\x10\xb0AZ\xc2z\xc0\xc4M\n\x86\xfbC\x83\xc5\xfc\x87X\xd2\xd0\x93\x9b\xff7\xfe\xb1'
        b'\xa1g\xe1>"\xf2\x103\xd5\x16K\x1a\xe6=\x16\xa2y<\xfc\x8c\xd1\x89]{\'R\x9e\x1d\x135\x8d\xee\xfd\xb0s\x80B\x9f\xd4qP,r\x8c70\x99\xd3\xd9g\xec,P\xc6\x0c8\xfbr\x1fO\xd3\xf2\x96\xcd'
        b'|s!x\xdc9\xde\x15#\xe8\x9ee\xc1\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__fi'
        b'le__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x03\x00\x08\x01\x03'
        b'\x00\x11\x01'
    ))
